% Auto-generated chapter 30 for bukhari
% Hadiths in this chapter: 112

\hadithdefcmd{bukhari}{1891}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ أَبِي سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، أَنَّ أَعْرَابِيًّا، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثَائِرَ الرَّأْسِ فَقَالَ يَا رَسُولَ اللَّهِ أَخْبِرْنِي مَاذَا فَرَضَ اللَّهُ عَلَىَّ مِنَ الصَّلاَةِ فَقَالَ ‏"‏ الصَّلَوَاتِ الْخَمْسَ، إِلاَّ أَنْ تَطَّوَّعَ شَيْئًا ‏"‏‏.‏ فَقَالَ أَخْبِرْنِي مَا فَرَضَ اللَّهُ عَلَىَّ مِنَ الصِّيَامِ فَقَالَ ‏"‏ شَهْرَ رَمَضَانَ، إِلاَّ أَنْ تَطَّوَّعَ شَيْئًا ‏"‏‏.‏ فَقَالَ أَخْبِرْنِي بِمَا فَرَضَ اللَّهُ عَلَىَّ مِنَ الزَّكَاةِ فَقَالَ فَأَخْبَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم شَرَائِعَ الإِسْلاَمِ‏.‏ قَالَ وَالَّذِي أَكْرَمَكَ لاَ أَتَطَوَّعُ شَيْئًا، وَلاَ أَنْقُصُ مِمَّا فَرَضَ اللَّهُ عَلَىَّ شَيْئًا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفْلَحَ إِنْ صَدَقَ، أَوْ دَخَلَ الْجَنَّةَ إِنْ صَدَقَ ‏"‏‏.‏\hadithno{1891}\hadithtrans{Narrated Talha bin 'Ubaidullah:A bedouin with unkempt hair came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Inform me what Allah has made compulsory for me as regards the prayers." He replied: "You have to offer perfectly the five compulsory prayers in a day and night (24 hours), unless you want to pray Nawafil." The bedouin further asked, "Inform me what Allah has made compulsory for me as regards fasting." He replied, "You have to fast during the whole month of Ramadan, unless you want to fast more as Nawafil." The bedouin further asked, "Tell me how much Zakat Allah has enjoined on me." Thus, Allah's Messenger (ﷺ) informed him about all the rules (i.e. fundamentals) of Islam. The bedouin then said, "By Him Who has honored you, I will neither perform any Nawafil nor will I decrease what Allah has enjoined on me. Allah's Messenger (ﷺ) said, "If he is saying the truth, he will succeed (or he will be granted Paradise)}}
\hadithdefcmd{bukhari}{1892}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ صَامَ النَّبِيُّ صلى الله عليه وسلم عَاشُورَاءَ، وَأَمَرَ بِصِيَامِهِ‏.‏ فَلَمَّا فُرِضَ رَمَضَانُ تُرِكَ‏.‏ وَكَانَ عَبْدُ اللَّهِ لاَ يَصُومُهُ، إِلاَّ أَنْ يُوَافِقَ صَوْمَهُ‏.‏\hadithno{1892}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) observed the fast on the 10th of Muharram ('Ashura), and ordered (Muslims) to fast on that day, but when the fasting of the month of Ramadan was prescribed, the fasting of the 'Ashura' was abandoned. `Abdullah did not use to fast on that day unless it coincided with his routine fasting by chance}}
\hadithdefcmd{bukhari}{1893}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ عِرَاكَ بْنَ مَالِكٍ، حَدَّثَهُ أَنَّ عُرْوَةَ أَخْبَرَهُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ قُرَيْشًا، كَانَتْ تَصُومُ يَوْمَ عَاشُورَاءَ فِي الْجَاهِلِيَّةِ، ثُمَّ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصِيَامِهِ حَتَّى فُرِضَ رَمَضَانُ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَاءَ فَلْيَصُمْهُ، وَمَنْ شَاءَ أَفْطَرَ ‏"‏‏.‏\hadithno{1893}\hadithtrans{Narrated `Aisha:(The tribe of) Quraish used to fast on the day of Ashura' in the Pre-Islamic period, and then Allah's Apostle ordered (Muslims) to fast on it till the fasting in the month of Ramadan was prescribed; whereupon the Prophet (ﷺ) said, "He who wants to fast (on 'Ashura') may fast, and he who does not want to fast may not fast}}
\hadithdefcmd{bukhari}{1894}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الصِّيَامُ جُنَّةٌ، فَلاَ يَرْفُثْ وَلاَ يَجْهَلْ، وَإِنِ امْرُؤٌ قَاتَلَهُ أَوْ شَاتَمَهُ فَلْيَقُلْ إِنِّي صَائِمٌ‏.‏ مَرَّتَيْنِ، وَالَّذِي نَفْسِي بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ تَعَالَى مِنْ رِيحِ الْمِسْكِ، يَتْرُكُ طَعَامَهُ وَشَرَابَهُ وَشَهْوَتَهُ مِنْ أَجْلِي، الصِّيَامُ لِي، وَأَنَا أَجْزِي بِهِ، وَالْحَسَنَةُ بِعَشْرِ أَمْثَالِهَا ‏"‏‏.‏\hadithno{1894}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Fasting is a shield (or a screen or a shelter). So, the person observing fasting should avoid sexual relation with his wife and should not behave foolishly and impudently, and if somebody fights with him or abuses him, he should tell him twice, 'I am fasting." The Prophet (ﷺ) added, "By Him in Whose Hands my soul is, the smell coming out from the mouth of a fasting person is better in the sight of Allah than the smell of musk. (Allah says about the fasting person), 'He has left his food, drink and desires for My sake. The fast is for Me. So I will reward (the fasting person) for it and the reward of good deeds is multiplied ten times}}
\hadithdefcmd{bukhari}{1895}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا جَامِعٌ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ عُمَرُ ـ رضى الله عنه ـ مَنْ يَحْفَظُ حَدِيثًا عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْفِتْنَةِ قَالَ حُذَيْفَةُ أَنَا سَمِعْتُهُ يَقُولُ ‏ "‏ فِتْنَةُ الرَّجُلِ فِي أَهْلِهِ وَمَالِهِ وَجَارِهِ تُكَفِّرُهَا الصَّلاَةُ وَالصِّيَامُ وَالصَّدَقَةُ ‏"‏‏.‏ قَالَ لَيْسَ أَسْأَلُ عَنْ ذِهِ، إِنَّمَا أَسْأَلُ عَنِ الَّتِي تَمُوجُ كَمَا يَمُوجُ الْبَحْرُ‏.‏ قَالَ وَإِنَّ دُونَ ذَلِكَ بَابًا مُغْلَقًا‏.‏ قَالَ فَيُفْتَحُ أَوْ يُكْسَرُ قَالَ يُكْسَرُ‏.‏ قَالَ ذَاكَ أَجْدَرُ أَنْ لاَ يُغْلَقَ إِلَى يَوْمِ الْقِيَامَةِ‏.‏ فَقُلْنَا لِمَسْرُوقٍ سَلْهُ أَكَانَ عُمَرُ يَعْلَمُ مَنِ الْبَابُ فَسَأَلَهُ فَقَالَ نَعَمْ، كَمَا يَعْلَمُ أَنَّ دُونَ غَدٍ اللَّيْلَةَ‏.‏\hadithno{1895}\hadithtrans{Narrated Abu Wail from Hudhaifa:`Umar asked the people, "Who remembers the narration of the Prophet (ﷺ) about the affliction?" Hudhaifa said, "I heard the Prophet (ﷺ) saying, 'The affliction of a person in his property, family and neighbors is expiated by his prayers, fasting, and giving in charity." `Umar said, "I do not ask about that, but I ask about those afflictions which will spread like the waves of the sea." Hudhaifa replied, "There is a closed gate in front of those afflictions." `Umar asked, "Will that gate be opened or broken?" He replied, "It will be broken." `Umar said, "Then the gate will not be closed again till the Day of Resurrection." We said to Masruq, "Would you ask Hudhaifa whether `Umar knew what that gate symbolized?" He asked him and he replied "He (`Umar) knew it as one knows that there will be night before tomorrow, morning}}
\hadithdefcmd{bukhari}{1896}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ بَابًا يُقَالُ لَهُ الرَّيَّانُ، يَدْخُلُ مِنْهُ الصَّائِمُونَ يَوْمَ الْقِيَامَةِ، لاَ يَدْخُلُ مِنْهُ أَحَدٌ غَيْرُهُمْ يُقَالُ أَيْنَ الصَّائِمُونَ فَيَقُومُونَ، لاَ يَدْخُلُ مِنْهُ أَحَدٌ غَيْرُهُمْ، فَإِذَا دَخَلُوا أُغْلِقَ، فَلَمْ يَدْخُلْ مِنْهُ أَحَدٌ ‏"‏‏.‏\hadithno{1896}\hadithtrans{Narrated Sahl:The Prophet (ﷺ) said, "There is a gate in Paradise called Ar-Raiyan, and those who observe fasts will enter through it on the Day of Resurrection and none except them will enter through it. It will be said, 'Where are those who used to observe fasts?' They will get up, and none except them will enter through it. After their entry the gate will be closed and nobody will enter through it}}
\hadithdefcmd{bukhari}{1897}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنِي مَعْنٌ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ نُودِيَ مِنْ أَبْوَابِ الْجَنَّةِ يَا عَبْدَ اللَّهِ، هَذَا خَيْرٌ‏.‏ فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ دُعِيَ مِنْ باب الصَّلاَةِ، وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ دُعِيَ مِنْ باب الْجِهَادِ، وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ باب الرَّيَّانِ، وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ دُعِيَ مِنْ باب الصَّدَقَةِ ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ ـ رضى الله عنه ـ بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ، مَا عَلَى مَنْ دُعِيَ مِنْ تِلْكَ الأَبْوَابِ مِنْ ضَرُورَةٍ، فَهَلْ يُدْعَى أَحَدٌ مِنْ تِلْكَ الأَبْوَابِ كُلِّهَا قَالَ ‏"‏ نَعَمْ‏.‏ وَأَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏‏.‏\hadithno{1897}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever gives two kinds (of things or property) in charity for Allah's Cause, will be called from the gates of Paradise and will be addressed, 'O slaves of Allah! Here is prosperity.' So, whoever was amongst the people who used to offer their prayers, will be called from the gate of the prayer; and whoever was amongst the people who used to participate in Jihad, will be called from the gate of Jihad; and whoever was amongst those who used to observe fasts, will be called from the gate of Ar-Raiyan; whoever was amongst those who used to give in charity, will be called from the gate of charity." Abu Bakr said, "Let my parents be sacrificed for you, O Allah's Messenger (ﷺ)! No distress or need will befall him who will be called from those gates. Will there be any one who will be called from all these gates?" The Prophet (ﷺ) replied, "Yes, and I hope you will be one of them}}
\hadithdefcmd{bukhari}{1898}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ أَبِي سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَاءَ رَمَضَانُ فُتِحَتْ أَبْوَابُ الْجَنَّةِ ‏"‏‏.‏\hadithno{1898}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When Ramadan begins, the gates of Paradise are opened}}
\hadithdefcmd{bukhari}{1899}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي أَنَسٍ، مَوْلَى التَّيْمِيِّينَ أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ شَهْرُ رَمَضَانَ فُتِّحَتْ أَبْوَابُ السَّمَاءِ، وَغُلِّقَتْ أَبْوَابُ جَهَنَّمَ، وَسُلْسِلَتِ الشَّيَاطِينُ ‏"‏‏.‏\hadithno{1899}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the month of Ramadan starts, the gates of the heaven are opened and the gates of Hell are closed and the devils are chained}}
\hadithdefcmd{bukhari}{1900}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمٌ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا رَأَيْتُمُوهُ فَصُومُوا، وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا، فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ‏"‏‏.‏ وَقَالَ غَيْرُهُ عَنِ اللَّيْثِ حَدَّثَنِي عُقَيْلٌ وَيُونُسُ لِهِلاَلِ رَمَضَانَ‏.‏\hadithno{1900}\hadithtrans{Narrated Ibn `Umar:I heard Allah's Messenger (ﷺ) saying, "When you see the crescent (of the month of Ramadan), start fasting, and when you see the crescent (of the month of Shawwal), stop fasting; and if the sky is overcast (and you can't see it) then regard the month of Ramadan as of 30 days}}
\hadithdefcmd{bukhari}{1901}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ، وَمَنْ صَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{1901}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever established prayers on the night of Qadr out of sincere faith and hoping for a reward from Allah, then all his previous sins will be forgiven; and whoever fasts in the month of Ramadan out of sincere faith, and hoping for a reward from Allah, then all his previous sins will be forgiven}}
\hadithdefcmd{bukhari}{1902}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم أَجْوَدَ النَّاسِ بِالْخَيْرِ، وَكَانَ أَجْوَدُ مَا يَكُونُ فِي رَمَضَانَ، حِينَ يَلْقَاهُ جِبْرِيلُ، وَكَانَ جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ يَلْقَاهُ كُلَّ لَيْلَةٍ فِي رَمَضَانَ حَتَّى يَنْسَلِخَ، يَعْرِضُ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم الْقُرْآنَ، فَإِذَا لَقِيَهُ جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ كَانَ أَجْوَدَ بِالْخَيْرِ مِنَ الرِّيحِ الْمُرْسَلَةِ‏.‏\hadithno{1902}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was the most generous amongst the people, and he used to be more so in the month of Ramadan when Gabriel visited him, and Gabriel used to meet him on every night of Ramadan till the end of the month. The Prophet (ﷺ) used to recite the Holy Qur'an to Gabriel, and when Gabriel met him, he used to be more generous than a fast wind (which causes rain and welfare)}}
\hadithdefcmd{bukhari}{1903}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَمْ يَدَعْ قَوْلَ الزُّورِ وَالْعَمَلَ بِهِ فَلَيْسَ لِلَّهِ حَاجَةٌ فِي أَنْ يَدَعَ طَعَامَهُ وَشَرَابَهُ ‏"‏‏.‏\hadithno{1903}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever does not give up forged speech and evil actions, Allah is not in need of his leaving his food and drink (i.e. Allah will not accept his fasting)}}
\hadithdefcmd{bukhari}{1904}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ أَبِي صَالِحٍ الزَّيَّاتِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ كُلُّ عَمَلِ ابْنِ آدَمَ لَهُ إِلاَّ الصِّيَامَ، فَإِنَّهُ لِي، وَأَنَا أَجْزِي بِهِ‏.‏ وَالصِّيَامُ جُنَّةٌ، وَإِذَا كَانَ يَوْمُ صَوْمِ أَحَدِكُمْ، فَلاَ يَرْفُثْ وَلاَ يَصْخَبْ، فَإِنْ سَابَّهُ أَحَدٌ، أَوْ قَاتَلَهُ فَلْيَقُلْ إِنِّي امْرُؤٌ صَائِمٌ‏.‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ، لِلصَّائِمِ فَرْحَتَانِ يَفْرَحُهُمَا إِذَا أَفْطَرَ فَرِحَ، وَإِذَا لَقِيَ رَبَّهُ فَرِحَ بِصَوْمِهِ ‏"‏‏.‏\hadithno{1904}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, 'All the deeds of Adam's sons (people) are for them, except fasting which is for Me, and I will give the reward for it.' Fasting is a shield or protection from the fire and from committing sins. If one of you is fasting, he should avoid sexual relation with his wife and quarreling, and if somebody should fight or quarrel with him, he should say, 'I am fasting.' By Him in Whose Hands my soul is' The unpleasant smell coming out from the mouth of a fasting person is better in the sight of Allah than the smell of musk. There are two pleasures for the fasting person, one at the time of breaking his fast, and the other at the time when he will meet his Lord; then he will be pleased because of his fasting}}
\hadithdefcmd{bukhari}{1905}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ بَيْنَا أَنَا أَمْشِي، مَعَ عَبْدِ اللَّهِ ـ رضى الله عنه ـ فَقَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَنِ اسْتَطَاعَ الْبَاءَةَ فَلْيَتَزَوَّجْ، فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ، وَمَنْ لَمْ يَسْتَطِعْ فَعَلَيْهِ بِالصَّوْمِ، فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏‏.‏\hadithno{1905}\hadithtrans{Narrated 'Alqama:While I was walking with `Abdullah he said, "We were in the company of the Prophet (ﷺ) and he said, 'He who can afford to marry should marry, because it will help him refrain from looking at other women, and save his private parts from committing illegal sexual relation; and he who cannot afford to marry is advised to fast, as fasting will diminish his sexual power}}
\hadithdefcmd{bukhari}{1906}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ رَمَضَانَ فَقَالَ ‏ "‏ لاَ تَصُومُوا حَتَّى تَرَوُا الْهِلاَلَ، وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ، فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ‏"‏‏.‏\hadithno{1906}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) mentioned Ramadan and said, "Do not fast unless you see the crescent (of Ramadan), and do not give up fasting till you see the crescent (of Shawwal), but if the sky is overcast (if you cannot see it), then act on estimation (i.e. count Sha'ban as 30 days)}}
\hadithdefcmd{bukhari}{1907}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ لَيْلَةً، فَلاَ تَصُومُوا حَتَّى تَرَوْهُ، فَإِنْ غُمَّ عَلَيْكُمْ فَأَكْمِلُوا الْعِدَّةَ ثَلاَثِينَ ‏"‏‏.‏\hadithno{1907}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "The month (can be) 29 nights (i.e. days), and do not fast till you see the moon, and if the sky is overcast, then complete Sha'ban as thirty days}}
\hadithdefcmd{bukhari}{1908}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ جَبَلَةَ بْنِ سُحَيْمٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا ‏"‏‏.‏ وَخَنَسَ الإِبْهَامَ فِي الثَّالِثَةِ‏.‏\hadithno{1908}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The month is like this and this," (at the same time he showed the fingers of both his hands thrice) and left out one thumb on the third time}}
\hadithdefcmd{bukhari}{1909}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم أَوْ قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ صُومُوا لِرُؤْيَتِهِ، وَأَفْطِرُوا لِرُؤْيَتِهِ، فَإِنْ غُبِّيَ عَلَيْكُمْ فَأَكْمِلُوا عِدَّةَ شَعْبَانَ ثَلاَثِينَ ‏"‏‏.‏\hadithno{1909}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) or Abul-Qasim said, "Start fasting on seeing the crescent (of Ramadan), and give up fasting on seeing the crescent (of Shawwal), and if the sky is overcast (and you cannot see it), complete thirty days of Sha'ban}}
\hadithdefcmd{bukhari}{1910}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ عِكْرِمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم آلَى مِنْ نِسَائِهِ شَهْرًا، فَلَمَّا مَضَى تِسْعَةٌ وَعِشْرُونَ يَوْمًا غَدَا أَوْ رَاحَ فَقِيلَ لَهُ إِنَّكَ حَلَفْتَ أَنْ لاَ تَدْخُلَ شَهْرًا‏.‏ فَقَالَ ‏ "‏ إِنَّ الشَّهْرَ يَكُونُ تِسْعَةً وَعِشْرِينَ يَوْمًا ‏"‏‏.‏\hadithno{1910}\hadithtrans{Narrated Um Salama:The Prophet (ﷺ) vowed to keep aloof from his wives for a period of one month, and after the completion of 29 days he went either in the morning or in the afternoon to his wives. Someone said to him "You vowed that you would not go to your wives for one month." He replied, "The month is of 29 days}}
\hadithdefcmd{bukhari}{1911}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ آلَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نِسَائِهِ، وَكَانَتِ انْفَكَّتْ رِجْلُهُ، فَأَقَامَ فِي مَشْرُبَةٍ تِسْعًا وَعِشْرِينَ لَيْلَةً، ثُمَّ نَزَلَ فَقَالُوا يَا رَسُولَ اللَّهِ آلَيْتَ شَهْرًا‏.‏ فَقَالَ ‏ "‏ إِنَّ الشَّهْرَ يَكُونُ تِسْعًا وَعِشْرِينَ ‏"‏‏.‏\hadithno{1911}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) vowed to keep aloof from his wives for one month, and he had dislocation of his leg. So, he stayed in a Mashruba for 29 nights and then came down. Some people said, "O Allah's Messenger (ﷺ)! You vowed to stay aloof for one month," He replied, "The month is of 29 days}}
\hadithdefcmd{bukhari}{1912}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنِي مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ خَالِدٍ الْحَذَّاءِ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، عَنْ أَبِيهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ شَهْرَانِ لاَ يَنْقُصَانِ شَهْرَا عِيدٍ رَمَضَانُ وَذُو الْحَجَّةِ ‏"‏‏.‏\hadithno{1912}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said, "The two months of `Id i.e. Ramadan and Dhul-Hijja, do not decrease (in superiority)}}
\hadithdefcmd{bukhari}{1913}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الأَسْوَدُ بْنُ قَيْسٍ، حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو، أَنَّهُ سَمِعَ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّا أُمَّةٌ أُمِّيَّةٌ، لاَ نَكْتُبُ وَلاَ نَحْسُبُ الشَّهْرُ هَكَذَا وَهَكَذَا ‏"‏‏.‏ يَعْنِي مَرَّةً تِسْعَةً وَعِشْرِينَ، وَمَرَّةً ثَلاَثِينَ‏.‏\hadithno{1913}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "We are an illiterate nation; we neither write, nor know accounts. The month is like this and this, i.e. sometimes of 29 days and sometimes of thirty days}}
\hadithdefcmd{bukhari}{1914}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَقَدَّمَنَّ أَحَدُكُمْ رَمَضَانَ بِصَوْمِ يَوْمٍ أَوْ يَوْمَيْنِ، إِلاَّ أَنْ يَكُونَ رَجُلٌ كَانَ يَصُومُ صَوْمَهُ فَلْيَصُمْ ذَلِكَ الْيَوْمَ ‏"‏‏.‏\hadithno{1914}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "None of you should fast a day or two before the month of Ramadan unless he has the habit of fasting (Nawafil) (and if his fasting coincides with that day) then he can fast that day}}
\hadithdefcmd{bukhari}{1915}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ كَانَ أَصْحَابُ مُحَمَّدٍ صلى الله عليه وسلم إِذَا كَانَ الرَّجُلُ صَائِمًا، فَحَضَرَ الإِفْطَارُ، فَنَامَ قَبْلَ أَنْ يُفْطِرَ لَمْ يَأْكُلْ لَيْلَتَهُ وَلاَ يَوْمَهُ، حَتَّى يُمْسِيَ، وَإِنَّ قَيْسَ بْنَ صِرْمَةَ الأَنْصَارِيَّ كَانَ صَائِمًا، فَلَمَّا حَضَرَ الإِفْطَارُ أَتَى امْرَأَتَهُ، فَقَالَ لَهَا أَعِنْدَكِ طَعَامٌ قَالَتْ لاَ وَلَكِنْ أَنْطَلِقُ، فَأَطْلُبُ لَكَ‏.‏ وَكَانَ يَوْمَهُ يَعْمَلُ، فَغَلَبَتْهُ عَيْنَاهُ، فَجَاءَتْهُ امْرَأَتُهُ، فَلَمَّا رَأَتْهُ قَالَتْ خَيْبَةً لَكَ‏.‏ فَلَمَّا انْتَصَفَ النَّهَارُ غُشِيَ عَلَيْهِ، فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏أُحِلَّ لَكُمْ لَيْلَةَ الصِّيَامِ الرَّفَثُ إِلَى نِسَائِكُمْ‏\}‏ فَفَرِحُوا بِهَا فَرَحًا شَدِيدًا، وَنَزَلَتْ ‏\{‏وَكُلُوا وَاشْرَبُوا حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ‏\}‏‏.‏\hadithno{1915}\hadithtrans{Narrated Al-Bara:It was the custom among the companions of Muhammad that if any of them was fasting and the food was presented (for breaking his fast), but he slept before eating, he would not eat that night and the following day till sunset. Qais bin Sirma-al-Ansari was fasting and came to his wife at the time of Iftar (breaking one's fast) and asked her whether she had anything to eat. She replied, "No, but I would go and bring some for you." He used to do hard work during the day, so he was overwhelmed by sleep and slept. When his wife came and saw him, she said, "Disappointment for you." When it was midday on the following day, he fainted and the Prophet (ﷺ) was informed about the whole matter and the following verses were revealed: "You are permitted To go to your wives (for sexual relation) At the night of fasting." So, they were overjoyed by it. And then Allah also revealed: "And eat and drink Until the white thread Of dawn appears to you Distinct from the black thread (of the night)}}
\hadithdefcmd{bukhari}{1916}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هُشَيْمٌ، قَالَ أَخْبَرَنِي حُصَيْنُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ ‏\{‏حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ‏\}‏ عَمَدْتُ إِلَى عِقَالٍ أَسْوَدَ وَإِلَى عِقَالٍ أَبْيَضَ، فَجَعَلْتُهُمَا تَحْتَ وِسَادَتِي، فَجَعَلْتُ أَنْظُرُ فِي اللَّيْلِ، فَلاَ يَسْتَبِينُ لِي، فَغَدَوْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ لَهُ ذَلِكَ فَقَالَ ‏"‏ إِنَّمَا ذَلِكَ سَوَادُ اللَّيْلِ وَبَيَاضُ النَّهَارِ ‏"‏‏.‏\hadithno{1916}\hadithtrans{Narrated `Adi bin Hatim:When the above verses were revealed: 'Until the white thread appears to you, distinct from the black thread,' I took two (hair) strings, one black and the other white, and kept them under my pillow and went on looking at them throughout the night but could not make anything out of it. So, the next morning I went to Allah's Messenger (ﷺ) and told him the whole story. He explained to me, "That verse means the darkness of the night and the whiteness of the dawn}}
\hadithdefcmd{bukhari}{1917}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ، ح‏.‏ حَدَّثَنِي سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، مُحَمَّدُ بْنُ مُطَرِّفٍ قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ أُنْزِلَتْ ‏\{‏وَكُلُوا وَاشْرَبُوا حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ‏\}‏ وَلَمْ يَنْزِلْ مِنَ الْفَجْرِ، فَكَانَ رِجَالٌ إِذَا أَرَادُوا الصَّوْمَ رَبَطَ أَحَدُهُمْ فِي رِجْلِهِ الْخَيْطَ الأَبْيَضَ وَالْخَيْطَ الأَسْوَدَ، وَلَمْ يَزَلْ يَأْكُلُ حَتَّى يَتَبَيَّنَ لَهُ رُؤْيَتُهُمَا، فَأَنْزَلَ اللَّهُ بَعْدُ ‏\{‏مِنَ الْفَجْرِ‏\}‏ فَعَلِمُوا أَنَّهُ إِنَّمَا يَعْنِي اللَّيْلَ وَالنَّهَارَ‏.‏\hadithno{1917}\hadithtrans{Narrated Sahl bin Sa`d:When the following verses were revealed: 'Eat and drink until the white thread appears to you, distinct from the black thread' and of dawn was not revealed, some people who intended to fast, tied black and white threads to their legs and went on eating till they differentiated between the two. Allah then revealed the words, 'of dawn', and it became clear that meant night and day}}
\hadithdefcmd{bukhari}{1919}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ‏.‏وَالْقَاسِمِ بْنِ مُحَمَّدٍ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ بِلاَلاً، كَانَ يُؤَذِّنُ بِلَيْلٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُوا وَاشْرَبُوا حَتَّى يُؤَذِّنَ ابْنُ أُمِّ مَكْتُومٍ، فَإِنَّهُ لاَ يُؤَذِّنُ حَتَّى يَطْلُعَ الْفَجْرُ ‏"‏‏.‏ قَالَ الْقَاسِمُ وَلَمْ يَكُنْ بَيْنَ أَذَانِهِمَا إِلاَّ أَنْ يَرْقَى ذَا وَيَنْزِلَ ذَا‏.‏\hadithno{1919}\hadithtrans{Narrated `Aisha:Bilal used to pronounce the Adhan at night, so Allah's Messenger (ﷺ)? said, "Carry on taking your meals (eat and drink) till Ibn Um Maktum pronounces the Adhan, for he does not pronounce it till it is dawn}}
\hadithdefcmd{bukhari}{1920}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ قَالَ كُنْتُ أَتَسَحَّرُ فِي أَهْلِي، ثُمَّ تَكُونُ سُرْعَتِي أَنْ أُدْرِكَ السُّجُودَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1920}\hadithtrans{Narrated Sahl bin Sa`d:I used to take my Suhur meals with my family and then hurry up for presenting myself for the (Fajr) prayer with Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{1921}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ ـ رضى الله عنه ـ قَالَ تَسَحَّرْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَامَ إِلَى الصَّلاَةِ‏.‏ قُلْتُ كَمْ كَانَ بَيْنَ الأَذَانِ وَالسَّحُورِ قَالَ قَدْرُ خَمْسِينَ آيَةً‏.‏\hadithno{1921}\hadithtrans{Narrated Anas:Zaid bin Thabit said, "We took the Suhur with the Prophet (ﷺ) . Then he stood for the prayer." I asked, "What was the interval between the Suhur and the Adhan?" He replied, "The interval was sufficient to recite fifty verses of the Qur'an}}
\hadithdefcmd{bukhari}{1922}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَاصَلَ فَوَاصَلَ النَّاسُ فَشَقَّ عَلَيْهِمْ، فَنَهَاهُمْ‏.‏ قَالُوا إِنَّكَ تُوَاصِلُ‏.‏ قَالَ ‏ "‏ لَسْتُ كَهَيْئَتِكُمْ، إِنِّي أَظَلُّ أُطْعَمُ وَأُسْقَى ‏"‏‏.‏\hadithno{1922}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) fasted for days continuously; the people also did the same but it was difficult for them. So, the Prophet (ﷺ) forbade them (to fast continuously for more than one day). They said, "But you fast without break (no food was taken in the evening or in the morning)." The Prophet (ﷺ) replied, "I am not like you, for I am provided with food and drink (by Allah)}}
\hadithdefcmd{bukhari}{1923}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السَّحُورِ بَرَكَةً ‏"‏‏.‏\hadithno{1923}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Take Suhur as there is a blessing in it}}
\hadithdefcmd{bukhari}{1924}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ رَجُلاً يُنَادِي فِي النَّاسِ، يَوْمَ عَاشُورَاءَ ‏ "‏ أَنْ مَنْ أَكَلَ فَلْيُتِمَّ أَوْ فَلْيَصُمْ، وَمَنْ لَمْ يَأْكُلْ فَلاَ يَأْكُلْ ‏"‏‏.‏\hadithno{1924}\hadithtrans{Narrated Salama bin Al-Akwa`:Once the Prophet (ﷺ) ordered a person on 'Ashura' (the tenth of Muharram) to announce, "Whoever has eaten, should not eat any more, but fast, and who has not eaten should not eat, but complete his fast (till the end of the day)}}
\hadithdefcmd{bukhari}{1926}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامِ بْنِ الْمُغِيرَةِ أَنَّهُ سَمِعَ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ، قَالَ كُنْتُ أَنَا وَأَبِي، حِينَ دَخَلْنَا عَلَى عَائِشَةَ وَأُمِّ سَلَمَةَ ح‏.‏ حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّ أَبَاهُ عَبْدَ الرَّحْمَنِ، أَخْبَرَ مَرْوَانَ، أَنَّ عَائِشَةَ، وَأُمَّ سَلَمَةَ أَخْبَرَتَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُدْرِكُهُ الْفَجْرُ وَهُوَ جُنُبٌ مِنْ أَهْلِهِ، ثُمَّ يَغْتَسِلُ وَيَصُومُ‏.‏ وَقَالَ مَرْوَانُ لِعَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ أُقْسِمُ بِاللَّهِ لَتُقَرِّعَنَّ بِهَا أَبَا هُرَيْرَةَ‏.‏ وَمَرْوَانُ يَوْمَئِذٍ عَلَى الْمَدِينَةِ‏.‏ فَقَالَ أَبُو بَكْرٍ فَكَرِهَ ذَلِكَ عَبْدُ الرَّحْمَنِ، ثُمَّ قُدِّرَ لَنَا أَنْ نَجْتَمِعَ بِذِي الْحُلَيْفَةِ، وَكَانَتْ لأَبِي هُرَيْرَةَ هُنَالِكَ أَرْضٌ، فَقَالَ عَبْدُ الرَّحْمَنِ لأَبِي هُرَيْرَةَ إِنِّي ذَاكِرٌ لَكَ أَمْرًا، وَلَوْلاَ مَرْوَانُ أَقْسَمَ عَلَىَّ فِيهِ لَمْ أَذْكُرْهُ لَكَ‏.‏ فَذَكَرَ قَوْلَ عَائِشَةَ وَأُمِّ سَلَمَةَ‏.‏ فَقَالَ كَذَلِكَ حَدَّثَنِي الْفَضْلُ بْنُ عَبَّاسٍ، وَهُنَّ أَعْلَمُ، وَقَالَ هَمَّامٌ وَابْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِي هُرَيْرَةَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْمُرُ بِالْفِطْرِ‏.‏ وَالأَوَّلُ أَسْنَدُ‏.‏\hadithno{1926}\hadithtrans{Narrated `Aisha and Um Salama:At times Allah's Messenger (ﷺ) used to get up in the morning in the state of Janaba after having sexual relations with his wives. He would then take a bath and fast}}
\hadithdefcmd{bukhari}{1927}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُقَبِّلُ وَيُبَاشِرُ، وَهُوَ صَائِمٌ، وَكَانَ أَمْلَكَكُمْ لإِرْبِهِ‏.‏ وَقَالَ قَالَ ابْنُ عَبَّاسٍ ‏\{‏مَآرِبُ‏\}‏ حَاجَةٌ‏.‏ قَالَ طَاوُسٌ ‏\{‏أُولِي الإِرْبَةِ‏\}‏ الأَحْمَقُ لاَ حَاجَةَ لَهُ فِي النِّسَاءِ‏.‏\hadithno{1927}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to kiss and embrace (his wives) while he was fasting, and he had more power to control his desires than any of you. Said Jabir, "The person who gets discharge after casting a look (on his wife) should complete his fast}}
\hadithdefcmd{bukhari}{1928}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُقَبِّلُ بَعْضَ أَزْوَاجِهِ وَهُوَ صَائِمٌ‏.‏ ثُمَّ ضَحِكَتْ‏.‏\hadithno{1928}\hadithtrans{Narrated Hisham's father:Aisha said, "Allah's Messenger (ﷺ) used to kiss some of his wives while he was fasting," and then she smiled}}
\hadithdefcmd{bukhari}{1929}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامِ بْنِ أَبِي عَبْدِ اللَّهِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، عَنْ أُمِّهَا ـ رضى الله عنهما ـ قَالَتْ بَيْنَمَا أَنَا مَعَ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْخَمِيلَةِ إِذْ حِضْتُ فَانْسَلَلْتُ، فَأَخَذْتُ ثِيَابَ حِيضَتِي فَقَالَ ‏ "‏ مَا لَكِ أَنُفِسْتِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَدَخَلْتُ مَعَهُ فِي الْخَمِيلَةِ، وَكَانَتْ هِيَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلاَنِ مِنْ إِنَاءٍ وَاحِدٍ، وَكَانَ يُقَبِّلُهَا وَهُوَ صَائِمٌ‏.‏\hadithno{1929}\hadithtrans{Narrated Zainab:(daughter of Um Salama) that her mother said, "While I was (lying) with Allah's Messenger (ﷺ) underneath a woolen sheet, I got the menstruation, and then slipped away and put on the clothes (which I used to wear) in menses. He asked, "What is the matter? Did you get your menses?" I replied in the affirmative and then entered underneath that woolen sheet. I and Allah's Messenger (ﷺ) used to take a bath from one water pot and he used to kiss me while he was fasting}}
\hadithdefcmd{bukhari}{1930}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَأَبِي، بَكْرٍ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ كَانَ النَّبِيُّ صلى الله عليه وسلم يُدْرِكُهُ الْفَجْرُ ‏\{‏جُنُبًا‏\}‏ فِي رَمَضَانَ، مِنْ غَيْرِ حُلُمٍ فَيَغْتَسِلُ وَيَصُومُ‏.‏\hadithno{1930}\hadithtrans{Narrated `Aisha:(At times) in Ramadan the Prophet (ﷺ) used to take a bath in the morning not because of a wet dream and would continue his fast}}
\hadithdefcmd{bukhari}{1932}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامِ بْنِ الْمُغِيرَةِ أَنَّهُ سَمِعَ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ، كُنْتُ أَنَا وَأَبِي،، فَذَهَبْتُ مَعَهُ، حَتَّى دَخَلْنَا عَلَى عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَشْهَدُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم إِنْ كَانَ لَيُصْبِحُ جُنُبًا مِنْ جِمَاعٍ غَيْرِ احْتِلاَمٍ، ثُمَّ يَصُومُهُ‏.‏ ثُمَّ دَخَلْنَا عَلَى أُمِّ سَلَمَةَ، فَقَالَتْ مِثْلَ ذَلِكَ\hadithno{1932}\hadithtrans{Narrated Abu Bakr bin `Abdur-Rahman:My father and I went to `Aisha and she said, "I testify that Allah's Messenger (ﷺ) at times used to get up in the morning in a state of Janaba from sexual intercourse, not from a wet dream and then he would fast that day." Then he went to Um Salama and she also narrated a similar thing}}
\hadithdefcmd{bukhari}{1933}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا ابْنُ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَسِيَ فَأَكَلَ وَشَرِبَ فَلْيُتِمَّ صَوْمَهُ، فَإِنَّمَا أَطْعَمَهُ اللَّهُ وَسَقَاهُ ‏"‏‏.‏\hadithno{1933}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If somebody eats or drinks forgetfully then he should complete his fast, for what he has eaten or drunk, has been given to him by Allah}}
\hadithdefcmd{bukhari}{1934}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ حُمْرَانَ، رَأَيْتُ عُثْمَانَ ـ رضى الله عنه ـ تَوَضَّأَ، فَأَفْرَغَ عَلَى يَدَيْهِ ثَلاَثًا، ثُمَّ تَمَضْمَضَ وَاسْتَنْثَرَ، ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا، ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى إِلَى الْمَرْفِقِ ثَلاَثًا، ثُمَّ غَسَلَ يَدَهُ الْيُسْرَى إِلَى الْمَرْفِقِ ثَلاَثًا، ثُمَّ مَسَحَ بِرَأْسِهِ، ثُمَّ غَسَلَ رِجْلَهُ الْيُمْنَى ثَلاَثًا، ثُمَّ الْيُسْرَى ثَلاَثًا، ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا، ثُمَّ قَالَ ‏ "‏ مَنْ تَوَضَّأَ وُضُوئِي هَذَا، ثُمَّ يُصَلِّي رَكْعَتَيْنِ، لاَ يُحَدِّثُ نَفْسَهُ فِيهِمَا بِشَىْءٍ، إِلاَّ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{1934}\hadithtrans{Narrated Humran:I saw `Uthman performing ablution; he washed his hands thrice, rinsed his mouth and then washed his nose, by putting water in it and then blowing it out, and washed his face thrice, and then washed his right forearm up to the elbow thrice, and then the left-forearm up to the elbow thrice, then smeared his head with water, washed his right foot thrice, and then his left foot thrice and said, "I saw Allah's Apostle performing ablution similar to my present ablution, and then he said, 'Whoever performs ablution like my present ablution and then offers two rak`at in which he does not think of worldly things, all his previous sins will be forgiven}}
\hadithdefcmd{bukhari}{1935}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ يَزِيدَ بْنَ هَارُونَ، حَدَّثَنَا يَحْيَى ـ هُوَ ابْنُ سَعِيدٍ ـ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، أَخْبَرَهُ عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ بْنِ الْعَوَّامِ بْنِ خُوَيْلِدٍ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَخْبَرَهُ أَنَّهُ، سَمِعَ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ إِنَّ رَجُلاً أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّهُ احْتَرَقَ‏.‏ قَالَ ‏"‏ مَالَكَ ‏"‏‏.‏ قَالَ أَصَبْتُ أَهْلِي فِي رَمَضَانَ‏.‏ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِمِكْتَلٍ، يُدْعَى الْعَرَقَ فَقَالَ ‏"‏ أَيْنَ الْمُحْتَرِقُ ‏"‏‏.‏ قَالَ أَنَا‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهَذَا ‏"‏‏.‏\hadithno{1935}\hadithtrans{Narrated `Aisha:A man came to the Prophet (ﷺ) and said that he had been burnt (ruined). The Prophet (ﷺ) asked him what was the matter. He replied, "I had sexual intercourse with my wife in Ramadan (while I was fasting)." Then a basket full of dates was brought to the Prophet (ﷺ) and he asked, "Where is the burnt (ruined) man?" He replied, "I am present." The Prophet (ﷺ) told him to give that basket in charity (as expiation)}}
\hadithdefcmd{bukhari}{1936}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَمَا نَحْنُ جُلُوسٌ عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ جَاءَهُ رَجُلٌ، فَقَالَ يَا رَسُولَ اللَّهِ هَلَكْتُ‏.‏ قَالَ ‏"‏ مَا لَكَ ‏"‏‏.‏ قَالَ وَقَعْتُ عَلَى امْرَأَتِي وَأَنَا صَائِمٌ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ تَجِدُ رَقَبَةً تُعْتِقُهَا ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏‏.‏ قَالَ لاَ‏.‏ فَقَالَ ‏"‏ فَهَلْ تَجِدُ إِطْعَامَ سِتِّينَ مِسْكِينًا ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ فَمَكَثَ النَّبِيُّ صلى الله عليه وسلم، فَبَيْنَا نَحْنُ عَلَى ذَلِكَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِعَرَقٍ فِيهَا تَمْرٌ ـ وَالْعَرَقُ الْمِكْتَلُ ـ قَالَ ‏"‏ أَيْنَ السَّائِلُ ‏"‏‏.‏ فَقَالَ أَنَا‏.‏ قَالَ ‏"‏ خُذْهَا فَتَصَدَّقْ بِهِ ‏"‏‏.‏ فَقَالَ الرَّجُلُ أَعَلَى أَفْقَرَ مِنِّي يَا رَسُولَ اللَّهِ فَوَاللَّهِ مَا بَيْنَ لاَبَتَيْهَا ـ يُرِيدُ الْحَرَّتَيْنِ ـ أَهْلُ بَيْتٍ أَفْقَرُ مِنْ أَهْلِ بَيْتِي، فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم حَتَّى بَدَتْ أَنْيَابُهُ ثُمَّ قَالَ ‏"‏ أَطْعِمْهُ أَهْلَكَ ‏"‏‏.‏\hadithno{1936}\hadithtrans{Narrated Abu Huraira:While we were sitting with the Prophet (ﷺ) a man came and said, "O Allah's Messenger (ﷺ)! I have been ruined." Allah's Messenger (ﷺ) asked what was the matter with him. He replied "I had sexual intercourse with my wife while I was fasting." Allah's Messenger (ﷺ) asked him, "Can you afford to manumit a slave?" He replied in the negative. Allah's Messenger (ﷺ) asked him, "Can you fast for two successive months?" He replied in the negative. The Prophet (ﷺ) asked him, "Can you afford to feed sixty poor persons?" He replied in the negative. The Prophet (ﷺ) kept silent and while we were in that state, a big basket full of dates was brought to the Prophet (ﷺ) . He asked, "Where is the questioner?" He replied, "I (am here)." The Prophet (ﷺ) said (to him), "Take this (basket of dates) and give it in charity." The man said, "Should I give it to a person poorer than I? By Allah; there is no family between its (i.e. Medina's) two mountains who are poorer than I." The Prophet (ﷺ) smiled till his premolar teeth became visible and then said, 'Feed your family with it}}
\hadithdefcmd{bukhari}{1937}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ الأَخِرَ وَقَعَ عَلَى امْرَأَتِهِ فِي رَمَضَانَ‏.‏ فَقَالَ ‏"‏ أَتَجِدُ مَا تُحَرِّرُ رَقَبَةً ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَتَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ أَفَتَجِدُ مَا تُطْعِمُ بِهِ سِتِّينَ مِسْكِينًا ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِعَرَقٍ فِيهِ تَمْرٌ ـ وَهُوَ الزَّبِيلُ ـ قَالَ ‏"‏ أَطْعِمْ هَذَا عَنْكَ ‏"‏‏.‏ قَالَ عَلَى أَحْوَجَ مِنَّا مَا بَيْنَ لاَبَتَيْهَا أَهْلُ بَيْتٍ أَحْوَجُ مِنَّا‏.‏ قَالَ ‏"‏ فَأَطْعِمْهُ أَهْلَكَ ‏"‏‏.‏\hadithno{1937}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet (ﷺ) and said, "I had sexual intercourse with my wife on Ramadan (while fasting)." The Prophet (ﷺ) asked him, "Can you afford to manumit a slave?" He replied in the negative. The Prophet (ﷺ) asked him, "Can you fast for two successive months?" He replied in the negative. He asked him, "Can you afford to feed sixty poor persons?" He replied in the negative. (Abu Huraira added): Then a basket full of dates was brought to the Prophet (ﷺ) and he said (to that man), "Feed (poor people) with this by way of atonement." He said, "(Should I feed it) to poorer people than we? There is no poorer house than ours between its (Medina's) mountains." The Prophet (ﷺ) said, "Then feed your family with it}}
\hadithdefcmd{bukhari}{1938}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ، وَهْوَ مُحْرِمٌ وَاحْتَجَمَ وَهْوَ صَائِمٌ‏.‏\hadithno{1938}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was cupped while he was in the state of Ihram, and also while he was observing a fast}}
\hadithdefcmd{bukhari}{1939}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ صَائِمٌ‏.‏\hadithno{1939}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was cupped while he was fasting}}
\hadithdefcmd{bukhari}{1940}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ ثَابِتًا الْبُنَانِيَّ، يَسْأَلُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ أَكُنْتُمْ تَكْرَهُونَ الْحِجَامَةَ لِلصَّائِمِ قَالَ لاَ‏.‏ إِلاَّ مِنْ أَجْلِ الضَّعْفِ‏.‏ وَزَادَ شَبَابَةُ حَدَّثَنَا شُعْبَةُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1940}\hadithtrans{Narrated Thabit Al-Bunani:Anas bin Malik was asked whether they disliked the cupping for a fasting person. He replied in the negative and said, "Only if it causes weakness}}
\hadithdefcmd{bukhari}{1941}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، سَمِعَ ابْنَ أَبِي أَوْفَى ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَقَالَ لِرَجُلٍ ‏"‏ انْزِلْ فَاجْدَحْ لِي ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ الشَّمْسُ‏.‏ قَالَ ‏"‏ انْزِلْ فَاجْدَحْ لِي ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ الشَّمْسُ‏.‏ قَالَ ‏"‏ انْزِلْ فَاجْدَحْ لِي ‏"‏‏.‏ فَنَزَلَ، فَجَدَحَ لَهُ، فَشَرِبَ، ثُمَّ رَمَى بِيَدِهِ هَا هُنَا، ثُمَّ قَالَ ‏"‏ إِذَا رَأَيْتُمُ اللَّيْلَ أَقْبَلَ مِنْ هَا هُنَا فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏‏.‏ تَابَعَهُ جَرِيرٌ وَأَبُو بَكْرِ بْنُ عَيَّاشٍ عَنِ الشَّيْبَانِيِّ عَنِ ابْنِ أَبِي أَوْفَى قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ‏.‏\hadithno{1941}\hadithtrans{Narrated Ibn Abi `Aufa:We were in the company of Allah's Messenger (ﷺ) on a journey. He said to a man, "Get down and mix Sawiq (powdered barley) with water for me." The man said, "The sun (has not set yet), O Allah's Messenger (ﷺ)." The Prophet (ﷺ) again said to him, "Get down and mix Sawiq with water for me." The man again said, "O Allah's Messenger (ﷺ)! The sun!" The Prophet (ﷺ) said to him (for the third time) "Get down and mix Sawiq with water for me." The man dismounted and mixed Sawiq with water for him. The Prophet (ﷺ) drank it and then beckoned with his hand (towards the East) and said, "When you see the night falling from this side, then a fasting person should break his fast}}
\hadithdefcmd{bukhari}{1942}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّ حَمْزَةَ بْنَ عَمْرٍو الأَسْلَمِيَّ، قَالَ يَا رَسُولَ اللَّهِ إِنِّي أَسْرُدُ الصَّوْمَ‏.‏\hadithno{1942}\hadithtrans{Narrated `Aisha:Hamza bin `Amr Al-Aslami said, "O Allah's Messenger (ﷺ)! I fast continuously}}
\hadithdefcmd{bukhari}{1943}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ حَمْزَةَ بْنَ عَمْرٍو الأَسْلَمِيَّ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم أَأَصُومُ فِي السَّفَرِ وَكَانَ كَثِيرَ الصِّيَامِ‏.‏ فَقَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ، وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏‏.‏\hadithno{1943}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Hamza bin `Amr Al-Aslami asked the Prophet, "Should I fast while traveling?" The Prophet (ﷺ) replied, "You may fast if you wish, and you may not fast if you wish}}
\hadithdefcmd{bukhari}{1944}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى مَكَّةَ فِي رَمَضَانَ فَصَامَ حَتَّى بَلَغَ الْكَدِيدَ أَفْطَرَ، فَأَفْطَرَ النَّاسُ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَالْكَدِيدُ مَاءٌ بَيْنَ عُسْفَانَ وَقُدَيْدٍ‏.‏\hadithno{1944}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) set out for Mecca in Ramadan and he fasted, and when he reached Al-Kadid, he broke his fast and the people (with him) broke their fast too. (Abu `Abdullah said, "Al-Kadid is a land covered with water between Usfan and Qudaid)}}
\hadithdefcmd{bukhari}{1945}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، أَنَّ إِسْمَاعِيلَ بْنَ عُبَيْدِ اللَّهِ، حَدَّثَهُ عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ ـ رضى الله عنه ـ قَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ فِي يَوْمٍ حَارٍّ حَتَّى يَضَعَ الرَّجُلُ يَدَهُ عَلَى رَأْسِهِ مِنْ شِدَّةِ الْحَرِّ، وَمَا فِينَا صَائِمٌ إِلاَّ مَا كَانَ مِنَ النَّبِيِّ صلى الله عليه وسلم وَابْنِ رَوَاحَةَ‏.‏\hadithno{1945}\hadithtrans{Narrated Abu Ad-Darda:We set out with Allah's Messenger (ﷺ) on one of his journeys on a very hot day, and it was so hot that one had to put his hand over his head because of the severity of heat. None of us was fasting except the Prophet and Ibn Rawaha}}
\hadithdefcmd{bukhari}{1946}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الأَنْصَارِيُّ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ عَمْرِو بْنِ الْحَسَنِ بْنِ عَلِيٍّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهم ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ، فَرَأَى زِحَامًا، وَرَجُلاً قَدْ ظُلِّلَ عَلَيْهِ، فَقَالَ ‏"‏ مَا هَذَا ‏"‏‏.‏ فَقَالُوا صَائِمٌ‏.‏ فَقَالَ ‏"‏ لَيْسَ مِنَ الْبِرِّ الصَّوْمُ فِي السَّفَرِ ‏"‏‏.‏\hadithno{1946}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) was on a journey and saw a crowd of people, and a man was being shaded (by them). He asked, "What is the matter?" They said, "He (the man) is fasting." The Prophet (ﷺ) said, "It is not righteousness that you fast on a journey}}
\hadithdefcmd{bukhari}{1947}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا نُسَافِرُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَعِبِ الصَّائِمُ عَلَى الْمُفْطِرِ، وَلاَ الْمُفْطِرُ عَلَى الصَّائِمِ‏.‏\hadithno{1947}\hadithtrans{Narrated Anas bin Malik:We used to travel with the Prophet (ﷺ) and neither did the fasting persons criticize those who were not fasting, nor did those who were not fasting criticize the fasting ones}}
\hadithdefcmd{bukhari}{1948}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ، فَصَامَ حَتَّى بَلَغَ عُسْفَانَ، ثُمَّ دَعَا بِمَاءٍ فَرَفَعَهُ إِلَى يَدَيْهِ لِيُرِيَهُ النَّاسَ فَأَفْطَرَ، حَتَّى قَدِمَ مَكَّةَ، وَذَلِكَ فِي رَمَضَانَ فَكَانَ ابْنُ عَبَّاسٍ يَقُولُ قَدْ صَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَفْطَرَ، فَمَنْ شَاءَ صَامَ، وَمَنْ شَاءَ أَفْطَرَ‏.‏\hadithno{1948}\hadithtrans{Narrated Tawus:Ibn `Abbas said, "Allah's Messenger (ﷺ) set out from Medina to Mecca and he fasted till he reached 'Usfan, where he asked for water and raised his hand to let the people see him, and then broke the fast, and did not fast after that till he reached Mecca, and that happened in Ramadan." Ibn `Abbas used to say, "Allah's Messenger (ﷺ) (sometimes) fasted and (sometimes) did not fast during the journeys so whoever wished to fast could fast, and whoever wished not to fast, could do so}}
\hadithdefcmd{bukhari}{1949}{حَدَّثَنَا عَيَّاشٌ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَرَأَ فِدْيَةٌ طَعَامُ مَسَاكِينَ‏.‏ قَالَ هِيَ مَنْسُوخَةٌ‏.‏\hadithno{1949}\hadithtrans{Narrated Nafi`:Ibn `Umar recited the verse: "They had a choice either to fast or to feed a poor person for every day, and said that the order of this Verse was canceled}}
\hadithdefcmd{bukhari}{1950}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ كَانَ يَكُونُ عَلَىَّ الصَّوْمُ مِنْ رَمَضَانَ، فَمَا أَسْتَطِيعُ أَنْ أَقْضِيَ إِلاَّ فِي شَعْبَانَ‏.‏ قَالَ يَحْيَى الشُّغْلُ مِنَ النَّبِيِّ أَوْ بِالنَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1950}\hadithtrans{Narrated `Aisha:Sometimes I missed some days of Ramadan, but could not fast in lieu of them except in the month of Sha'ban." Said Yahya, a sub-narrator, "She used to be busy serving the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{1951}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي زَيْدٌ، عَنْ عِيَاضٍ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَلَيْسَ إِذَا حَاضَتْ لَمْ تُصَلِّ، وَلَمْ تَصُمْ فَذَلِكَ نُقْصَانُ دِينِهَا ‏"‏‏.‏\hadithno{1951}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) said, "Isn't it true that a woman does not pray and does not fast on menstruating? And that is the defect (a loss) in her religion}}
\hadithdefcmd{bukhari}{1952}{حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى بْنِ أَعْيَنَ، حَدَّثَنَا أَبِي، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرٍ، حَدَّثَهُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَاتَ وَعَلَيْهِ صِيَامٌ صَامَ عَنْهُ وَلِيُّهُ ‏"‏‏.‏ تَابَعَهُ ابْنُ وَهْبٍ عَنْ عَمْرٍو‏.‏ وَرَوَاهُ يَحْيَى بْنُ أَيُّوبَ عَنِ ابْنِ أَبِي جَعْفَرٍ‏.‏\hadithno{1952}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "Whoever died and he ought to have fasted (the missed days of Ramadan) then his guardians must fast on his behalf}}
\hadithdefcmd{bukhari}{1953}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا زَائِدَةُ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي مَاتَتْ، وَعَلَيْهَا صَوْمُ شَهْرٍ، أَفَأَقْضِيهِ عَنْهَا قَالَ ‏ "‏ نَعَمْ ـ قَالَ ـ فَدَيْنُ اللَّهِ أَحَقُّ أَنْ يُقْضَى ‏"‏‏.‏ قَالَ سُلَيْمَانُ فَقَالَ الْحَكَمُ وَسَلَمَةُ، وَنَحْنُ جَمِيعًا جُلُوسٌ حِينَ حَدَّثَ مُسْلِمٌ بِهَذَا الْحَدِيثِ ـ قَالاَ ـ سَمِعْنَا مُجَاهِدًا يَذْكُرُ هَذَا عَنِ ابْنِ عَبَّاسٍ‏.‏ وَيُذْكَرُ عَنْ أَبِي خَالِدٍ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْحَكَمِ، وَمُسْلِمٍ الْبَطِينِ، وَسَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَعَطَاءٍ، وَمُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَتِ امْرَأَةٌ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أُخْتِي مَاتَتْ‏.‏ وَقَالَ يَحْيَى وَأَبُو مُعَاوِيَةَ حَدَّثَنَا الأَعْمَشُ عَنْ مُسْلِمٍ عَنْ سَعِيدٍ عَنِ ابْنِ عَبَّاسٍ قَالَتِ امْرَأَةٌ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أُمِّي مَاتَتْ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ عَنِ الْحَكَمِ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ قَالَتِ امْرَأَةٌ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا صَوْمُ نَذْرٍ‏.‏ وَقَالَ أَبُو حَرِيزٍ حَدَّثَنَا عِكْرِمَةُ عَنِ ابْنِ عَبَّاسٍ قَالَتِ امْرَأَةٌ لِلنَّبِيِّ صلى الله عليه وسلم مَاتَتْ أُمِّي وَعَلَيْهَا صَوْمُ خَمْسَةَ عَشَرَ يَوْمًا‏.‏\hadithno{1953}\hadithtrans{Narrated Ibn `Abbas:A man came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! My mother died and she ought to have fasted one month (for her missed Ramadan). Shall I fast on her behalf?" The Prophet (ﷺ) replied in the affirmative and said, "Allah's debts have more right to be paid." In another narration a woman is reported to have said, "My sister died..." Narrated Ibn `Abbas: A woman said to the Prophet (ﷺ) "My mother died and she had vowed to fast but she didn't fast." In another narration Ibn `Abbas is reported to have said, "A woman said to the Prophet, "My mother died while she ought to have fasted for fifteen days}}
\hadithdefcmd{bukhari}{1954}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ عَاصِمَ بْنَ عُمَرَ بْنِ الْخَطَّابِ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَقْبَلَ اللَّيْلُ مِنْ هَا هُنَا، وَأَدْبَرَ النَّهَارُ مِنْ هَا هُنَا، وَغَرَبَتِ الشَّمْسُ، فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏‏.‏\hadithno{1954}\hadithtrans{Narrated `Umar bin Al-Khattab:Allah's Messenger (ﷺ) said, "When night falls from this side and the day vanishes from this side and the sun sets, then the fasting person should break his fast}}
\hadithdefcmd{bukhari}{1955}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ، وَهُوَ صَائِمٌ، فَلَمَّا غَرَبَتِ الشَّمْسُ قَالَ لِبَعْضِ الْقَوْمِ ‏"‏ يَا فُلاَنُ قُمْ، فَاجْدَحْ لَنَا ‏"‏‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ، لَوْ أَمْسَيْتَ‏.‏ قَالَ ‏"‏ انْزِلْ، فَاجْدَحْ لَنَا ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ فَلَوْ أَمْسَيْتَ‏.‏ قَالَ ‏"‏ انْزِلْ، فَاجْدَحْ لَنَا ‏"‏‏.‏ قَالَ إِنَّ عَلَيْكَ نَهَارًا‏.‏ قَالَ ‏"‏ انْزِلْ، فَاجْدَحْ لَنَا ‏"‏‏.‏ فَنَزَلَ فَجَدَحَ لَهُمْ، فَشَرِبَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ إِذَا رَأَيْتُمُ اللَّيْلَ قَدْ أَقْبَلَ مِنْ هَا هُنَا، فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏‏.‏\hadithno{1955}\hadithtrans{Narrated `Abdullah bin Abi `Aufa:We were in the company of the Prophet (ﷺ) on a journey and he was fasting, and when the sun set, he addressed somebody, "O so-and-so, get up and mix Sawiq with water for us." He replied, "O Allah's Apostle! (Will you wait) till it is evening?" The Prophet (ﷺ) said, "Get down and mix Sawiq with water for us." He replied, "O Allah's Messenger (ﷺ)! (If you wait) till it is evening." The Prophet (ﷺ) said again, "Get down and mix Sawiq with water for us." He replied, "It is still daytime."(1) The Prophet (ﷺ) said again, "Get down and mix Sawiq with water for us." He got down and mixed Sawiq for them. The Prophet (ﷺ) drank it and then said, "When you see night falling from this side, the fasting person should break his fast}}
\hadithdefcmd{bukhari}{1956}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الشَّيْبَانِيُّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى ـ رضى الله عنه ـ قَالَ سِرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ صَائِمٌ، فَلَمَّا غَرَبَتِ الشَّمْسُ قَالَ ‏"‏ انْزِلْ، فَاجْدَحْ لَنَا ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، لَوْ أَمْسَيْتَ‏.‏ قَالَ ‏"‏ انْزِلْ، فَاجْدَحْ لَنَا ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، إِنَّ عَلَيْكَ نَهَارًا‏.‏ قَالَ ‏"‏ انْزِلْ، فَاجْدَحْ لَنَا ‏"‏‏.‏ فَنَزَلَ، فَجَدَحَ، ثُمَّ قَالَ ‏"‏ إِذَا رَأَيْتُمُ اللَّيْلَ أَقْبَلَ مِنْ هَا هُنَا فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏‏.‏ وَأَشَارَ بِإِصْبَعِهِ قِبَلَ الْمَشْرِقِ‏.‏\hadithno{1956}\hadithtrans{Narrated `Abdullah bin Abi `Aufa:We were traveling with Allah's Messenger (ﷺ) and he was fasting, and when the sun set, he said to (someone), "Get down and mix Sawiq with water for us." He replied, "O Allah's Messenger (ﷺ)! (Will you wait) till it is evening?" The Prophet (ﷺ) again said, "Get down and mix Sawiq with water for us." He replied, "O Allah's Messenger (ﷺ)! It is still daytime." The Prophet (ﷺ) said again, "Get down and mix Sawiq with water for us." So, he got down and carried out that order. The Prophet (ﷺ) then said, "When you see night falling from this side, the fasting person should break his fast," and he beckoned with his finger towards the east}}
\hadithdefcmd{bukhari}{1957}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ النَّاسُ بِخَيْرٍ مَا عَجَّلُوا الْفِطْرَ ‏"‏‏.‏\hadithno{1957}\hadithtrans{Narrated Sahl bin Sa`d:Allah's Messenger (ﷺ) said, "The people will remain on the right path as long as they hasten the breaking of the fast}}
\hadithdefcmd{bukhari}{1958}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ سُلَيْمَانَ، عَنِ ابْنِ أَبِي أَوْفَى ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ، فَصَامَ حَتَّى أَمْسَى، قَالَ لِرَجُلٍ ‏"‏ انْزِلْ، فَاجْدَحْ لِي ‏"‏‏.‏ قَالَ لَوِ انْتَظَرْتَ حَتَّى تُمْسِيَ‏.‏ قَالَ ‏"‏ انْزِلْ، فَاجْدَحْ لِي، إِذَا رَأَيْتَ اللَّيْلَ قَدْ أَقْبَلَ مِنْ هَا هُنَا فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏‏.‏\hadithno{1958}\hadithtrans{Narrated Ibn Abi `Aufa:I was with the Prophet (ﷺ) on a journey, and he observed the fast till evening. The Prophet (ﷺ) said to a man, "Get down and mix Sawiq with water for me." He replied, "Will you wait till it is evening?" The Prophet said, "Get down and mix Sawiq with water for me; when you see night falling from this side, the fasting person should break his fast}}
\hadithdefcmd{bukhari}{1959}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ أَفْطَرْنَا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم يَوْمَ غَيْمٍ، ثُمَّ طَلَعَتِ الشَّمْسُ‏.‏ قِيلَ لِهِشَامٍ فَأُمِرُوا بِالْقَضَاءِ قَالَ بُدٌّ مِنْ قَضَاءٍ‏.‏ وَقَالَ مَعْمَرٌ سَمِعْتُ هِشَامًا لاَ أَدْرِي أَقْضَوْا أَمْ لاَ‏.‏\hadithno{1959}\hadithtrans{Narrated Abu Usama from Hisham bin 'Urwa from Fatima:Asma bint Abi Bakr said, "We broke our fast during the lifetime of the Prophet (ﷺ) on a cloudy day and then the sun appeared." Hisham was asked, "Were they ordered to fast in lieu of that day?" He replied, "It had to be made up for." Ma`mar said, "I heard Hisham saying, "I don't know whether they fasted in lieu of that day or not}}
\hadithdefcmd{bukhari}{1960}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا خَالِدُ بْنُ ذَكْوَانَ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذٍ، قَالَتْ أَرْسَلَ النَّبِيُّ صلى الله عليه وسلم غَدَاةَ عَاشُورَاءَ إِلَى قُرَى الأَنْصَارِ ‏ "‏ مَنْ أَصْبَحَ مُفْطِرًا فَلْيُتِمَّ بَقِيَّةَ يَوْمِهِ، وَمَنْ أَصْبَحَ صَائِمًا فَلْيَصُمْ ‏"‏‏.‏ قَالَتْ فَكُنَّا نَصُومُهُ بَعْدُ، وَنُصَوِّمُ صِبْيَانَنَا، وَنَجْعَلُ لَهُمُ اللُّعْبَةَ مِنَ الْعِهْنِ، فَإِذَا بَكَى أَحَدُهُمْ عَلَى الطَّعَامِ أَعْطَيْنَاهُ ذَاكَ، حَتَّى يَكُونَ عِنْدَ الإِفْطَارِ‏.‏\hadithno{1960}\hadithtrans{Narrated Ar-Rubai' bint Mu'awwidh:"The Prophet (ﷺ) sent a messenger to the village of the Ansar in the morning of the day of 'Ashura' (10th of Muharram) to announce: 'Whoever has eaten something should not eat but complete the fast, and whoever is observing the fast should complete it.' "She further said, "Since then we used to fast on that day regularly and also make our boys fast. We used to make toys of wool for the boys and if anyone of them cried for food, he was given those toys till it was the time of the breaking of the fast}}
\hadithdefcmd{bukhari}{1961}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنِي يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُوَاصِلُوا ‏"‏‏.‏ قَالُوا إِنَّكَ تُوَاصِلُ‏.‏ قَالَ ‏"‏ لَسْتُ كَأَحَدٍ مِنْكُمْ، إِنِّي أُطْعَمُ وَأُسْقَى، أَوْ إِنِّي أَبِيتُ أُطْعَمُ وَأُسْقَى ‏"‏‏.‏\hadithno{1961}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Do not practice Al-Wisal (fasting continuously without breaking one's fast in the evening or eating before the following dawn)." The people said to the Prophet, "But you practice Al- Wisal?" The Prophet (ﷺ) replied, "I am not like any of you, for I am given food and drink (by Allah) during the night}}
\hadithdefcmd{bukhari}{1962}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوِصَالِ‏.‏ قَالُوا إِنَّكَ تُوَاصِلُ‏.‏ قَالَ ‏ "‏ إِنِّي لَسْتُ مِثْلَكُمْ، إِنِّي أُطْعَمُ وَأُسْقَى ‏"‏‏.‏\hadithno{1962}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) forbade Al-Wisal. The people said (to him), "But you practice it?" He said, "I am not like you, for I am given food and drink by Allah}}
\hadithdefcmd{bukhari}{1963}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي ابْنُ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تُوَاصِلُوا، فَأَيُّكُمْ إِذَا أَرَادَ أَنْ يُوَاصِلَ فَلْيُوَاصِلْ حَتَّى السَّحَرِ ‏"‏‏.‏ قَالُوا فَإِنَّكَ تُوَاصِلُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ إِنِّي لَسْتُ كَهَيْئَتِكُمْ، إِنِّي أَبِيتُ لِي مُطْعِمٌ يُطْعِمُنِي وَسَاقٍ يَسْقِينِ ‏"‏‏.‏\hadithno{1963}\hadithtrans{Narrated Abu Sa`id:That he had heard the Prophet (ﷺ) saying, "Do not fast continuously (practice Al-Wisal), and if you intend to lengthen your fast, then carry it on only till the Suhur (before the following dawn)." The people said to him, "But you practice (Al-Wisal), O Allah's Messenger (ﷺ)!" He replied, "I am not similar to you, for during my sleep I have One Who makes me eat and drink}}
\hadithdefcmd{bukhari}{1964}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدٌ، قَالاَ أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوِصَالِ، رَحْمَةً لَهُمْ فَقَالُوا إِنَّكَ تُوَاصِلُ‏.‏ قَالَ ‏ "‏ إِنِّي لَسْتُ كَهَيْئَتِكُمْ، إِنِّي يُطْعِمُنِي رَبِّي وَيَسْقِينِ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ لَمْ يَذْكُرْ عُثْمَانُ رَحْمَةً لَهُمْ‏.‏\hadithno{1964}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) forbade Al-Wisal out of mercy to them. They said to him, "But you practice Al- Wisal?" He said, "I am not similar to you, for my Lord gives me food and drink}}
\hadithdefcmd{bukhari}{1965}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوِصَالِ فِي الصَّوْمِ فَقَالَ لَهُ رَجُلٌ مِنَ الْمُسْلِمِينَ إِنَّكَ تُوَاصِلُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَأَيُّكُمْ مِثْلِي إِنِّي أَبِيتُ يُطْعِمُنِي رَبِّي وَيَسْقِينِ ‏"‏‏.‏ فَلَمَّا أَبَوْا أَنْ يَنْتَهُوا عَنِ الْوِصَالِ وَاصَلَ بِهِمْ يَوْمًا ثُمَّ يَوْمًا، ثُمَّ رَأَوُا الْهِلاَلَ، فَقَالَ ‏"‏ لَوْ تَأَخَّرَ لَزِدْتُكُمْ ‏"‏‏.‏ كَالتَّنْكِيلِ لَهُمْ، حِينَ أَبَوْا أَنْ يَنْتَهُوا‏.‏\hadithno{1965}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade Al-Wisal in fasting. So, one of the Muslims said to him, "But you practice Al- Wisal. O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) replied, "Who amongst you is similar to me? I am given food and drink during my sleep by my Lord." So, when the people refused to stop Al-Wisal (fasting continuously), the Prophet (ﷺ) fasted day and night continuously along with them for a day and then another day and then they saw the crescent moon (of the month of Shawwal). The Prophet (ﷺ) said to them (angrily), "If It (the crescent) had not appeared, I would have made you fast for a longer period." That was as a punishment for them when they refused to stop (practicing Al-Wisal)}}
\hadithdefcmd{bukhari}{1966}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْوِصَالَ ‏"‏‏.‏ مَرَّتَيْنِ قِيلَ إِنَّكَ تُوَاصِلُ‏.‏ قَالَ ‏"‏ إِنِّي أَبِيتُ يُطْعِمُنِي رَبِّي وَيَسْقِينِ، فَاكْلَفُوا مِنَ الْعَمَلِ مَا تُطِيقُونَ ‏"‏‏.‏\hadithno{1966}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said twice, "(O you people) Be cautious! Do not practice Al-Wisal." The people said to him, "But you practice Al-Wisal?" The Prophet (ﷺ) replied, "My Lord gives me food and drink during my sleep. Do that much of deeds which is within your ability}}
\hadithdefcmd{bukhari}{1967}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنِي ابْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تُوَاصِلُوا، فَأَيُّكُمْ أَرَادَ أَنْ يُوَاصِلَ فَلْيُوَاصِلْ حَتَّى السَّحَرِ ‏"‏‏.‏ قَالُوا فَإِنَّكَ تُوَاصِلُ، يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ لَسْتُ كَهَيْئَتِكُمْ، إِنِّي أَبِيتُ لِي مُطْعِمٌ يُطْعِمُنِي وَسَاقٍ يَسْقِينِ ‏"‏‏.‏\hadithno{1967}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "Do not fast continuously day and night (practice Al-Wisal) and if anyone of you intends to fast continuously day and night, he should continue till the Suhur time." They said, "But you practice Al-Wisal, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said, "I am not similar to you;. during my sleep I have One Who makes me eat and drink}}
\hadithdefcmd{bukhari}{1968}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، حَدَّثَنَا أَبُو الْعُمَيْسِ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ آخَى النَّبِيُّ صلى الله عليه وسلم بَيْنَ سَلْمَانَ، وَأَبِي الدَّرْدَاءِ، فَزَارَ سَلْمَانُ أَبَا الدَّرْدَاءِ، فَرَأَى أُمَّ الدَّرْدَاءِ مُتَبَذِّلَةً‏.‏ فَقَالَ لَهَا مَا شَأْنُكِ قَالَتْ أَخُوكَ أَبُو الدَّرْدَاءِ لَيْسَ لَهُ حَاجَةٌ فِي الدُّنْيَا‏.‏ فَجَاءَ أَبُو الدَّرْدَاءِ، فَصَنَعَ لَهُ طَعَامًا‏.‏ فَقَالَ كُلْ‏.‏ قَالَ فَإِنِّي صَائِمٌ‏.‏ قَالَ مَا أَنَا بِآكِلٍ حَتَّى تَأْكُلَ‏.‏ قَالَ فَأَكَلَ‏.‏ فَلَمَّا كَانَ اللَّيْلُ ذَهَبَ أَبُو الدَّرْدَاءِ يَقُومُ‏.‏ قَالَ نَمْ‏.‏ فَنَامَ، ثُمَّ ذَهَبَ يَقُومُ‏.‏ فَقَالَ نَمْ‏.‏ فَلَمَّا كَانَ مِنْ آخِرِ اللَّيْلِ قَالَ سَلْمَانُ قُمِ الآنَ‏.‏ فَصَلَّيَا، فَقَالَ لَهُ سَلْمَانُ إِنَّ لِرَبِّكَ عَلَيْكَ حَقًّا، وَلِنَفْسِكَ عَلَيْكَ حَقًّا، وَلأَهْلِكَ عَلَيْكَ حَقًّا، فَأَعْطِ كُلَّ ذِي حَقٍّ حَقَّهُ‏.‏ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ صَدَقَ سَلْمَانُ ‏"‏‏.‏\hadithno{1968}\hadithtrans{Narrated Abu Juhaifa:The Prophet (ﷺ) made a bond of brotherhood between Salman and Abu Ad-Darda.' Salman paid a visit to Abu Ad-Darda' and found Um Ad-Darda' dressed in shabby clothes and asked her why she was in that state. She replied, "Your brother Abu Ad-Darda' is not interested in (the luxuries of) this world." In the meantime Abu Ad-Darda' came and prepared a meal for Salman. Salman requested Abu Ad- Darda' to eat (with him), but Abu Ad-Darda' said, "I am fasting." Salman said, "I am not going to eat unless you eat." So, Abu Ad-Darda' ate (with Salman). When it was night and (a part of the night passed), Abu Ad-Darda' got up (to offer the night prayer), but Salman told him to sleep and Abu Ad- Darda' slept. After sometime Abu Ad-Darda' again got up but Salman told him to sleep. When it was the last hours of the night, Salman told him to get up then, and both of them offered the prayer. Salman told Abu Ad-Darda', "Your Lord has a right on you, your soul has a right on you, and your family has a right on you; so you should give the rights of all those who has a right on you." Abu Ad- Darda' came to the Prophet (ﷺ) and narrated the whole story. The Prophet (ﷺ) said, "Salman has spoken the truth}}
\hadithdefcmd{bukhari}{1969}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ لاَ يُفْطِرُ، وَيُفْطِرُ حَتَّى نَقُولَ لاَ يَصُومُ‏.‏ فَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَكْمَلَ صِيَامَ شَهْرٍ إِلاَّ رَمَضَانَ، وَمَا رَأَيْتُهُ أَكْثَرَ صِيَامًا مِنْهُ فِي شَعْبَانَ‏.‏\hadithno{1969}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to fast till one would say that he would never stop fasting, and he would abandon fasting till one would say that he would never fast. I never saw Allah's Messenger (ﷺ) fasting for a whole month except the month of Ramadan, and did not see him fasting in any month more than in the month of Sha'ban}}
\hadithdefcmd{bukhari}{1970}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ حَدَّثَتْهُ قَالَتْ، لَمْ يَكُنِ النَّبِيُّ صلى الله عليه وسلم يَصُومُ شَهْرًا أَكْثَرَ مِنْ شَعْبَانَ، فَإِنَّهُ كَانَ يَصُومُ شَعْبَانَ كُلَّهُ، وَكَانَ يَقُولُ ‏ "‏ خُذُوا مِنَ الْعَمَلِ مَا تُطِيقُونَ، فَإِنَّ اللَّهَ لاَ يَمَلُّ حَتَّى تَمَلُّوا، وَأَحَبُّ الصَّلاَةِ إِلَى النَّبِيِّ صلى الله عليه وسلم مَا دُووِمَ عَلَيْهِ، وَإِنْ قَلَّتْ ‏"‏ وَكَانَ إِذَا صَلَّى صَلاَةً دَاوَمَ عَلَيْهَا‏.‏\hadithno{1970}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) never fasted in any month more than in the month of Sha'ban. He used to say, "Do those deeds which you can do easily, as Allah will not get tired (of giving rewards) till you get bored and tired (of performing religious deeds)." The most beloved prayer to the Prophet (ﷺ) was the one that was done regularly (throughout the life) even if it were little. And whenever the Prophet (ﷺ) offered a prayer he used to offer it regularly}}
\hadithdefcmd{bukhari}{1971}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ مَا صَامَ النَّبِيُّ صلى الله عليه وسلم شَهْرًا كَامِلاً قَطُّ غَيْرَ رَمَضَانَ، وَيَصُومُ حَتَّى يَقُولَ الْقَائِلُ لاَ وَاللَّهِ لاَ يُفْطِرُ، وَيُفْطِرُ حَتَّى يَقُولَ الْقَائِلُ لاَ وَاللَّهِ لاَ يَصُومُ‏.‏\hadithno{1971}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) never fasted a full month except the month of Ramadan, and he used to fast till one could say, "By Allah, he will never stop fasting," and he would abandon fasting till one would say, "By Allah, he will never fast}}
\hadithdefcmd{bukhari}{1972}{حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، أَنَّهُ سَمِعَ أَنَسًا ـ رضى الله عنه ـ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُفْطِرُ مِنَ الشَّهْرِ، حَتَّى نَظُنَّ أَنْ لاَ يَصُومَ مِنْهُ، وَيَصُومُ حَتَّى نَظُنَّ أَنْ لاَ يُفْطِرَ مِنْهُ شَيْئًا، وَكَانَ لاَ تَشَاءُ تَرَاهُ مِنَ اللَّيْلِ مُصَلِّيًا إِلاَّ رَأَيْتَهُ، وَلاَ نَائِمًا إِلاَّ رَأَيْتَهُ‏.‏ وَقَالَ سُلَيْمَانُ عَنْ حُمَيْدٍ أَنَّهُ سَأَلَ أَنَسًا فِي الصَّوْمِ‏.‏\hadithno{1972}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) used to leave fasting in a certain month till we thought that he would not fast in that month, and he used to fast in another month till we thought he would not stop fasting at all in that month. And if one wanted to see him praying at night, one could see him (in that condition), and if one wanted to see him sleeping at night, one could see him (in that condition) too}}
\hadithdefcmd{bukhari}{1973}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا أَبُو خَالِدٍ الأَحْمَرُ، أَخْبَرَنَا حُمَيْدٌ، قَالَ سَأَلْتُ أَنَسًا رضى الله عنه عَنْ صِيَامِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ مَا كُنْتُ أُحِبُّ أَنْ أَرَاهُ مِنَ الشَّهْرِ صَائِمًا إِلاَّ رَأَيْتُهُ وَلاَ مُفْطِرًا إِلاَّ رَأَيْتُهُ، وَلاَ مِنَ اللَّيْلِ قَائِمًا إِلاَّ رَأَيْتُهُ، وَلاَ نَائِمًا إِلاَّ رَأَيْتُهُ، وَلاَ مَسِسْتُ خَزَّةً وَلاَ حَرِيرَةً أَلْيَنَ مِنْ كَفِّ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَلاَ شَمِمْتُ مِسْكَةً وَلاَ عَبِيرَةً أَطْيَبَ رَائِحَةً مِنْ رَائِحَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1973}\hadithtrans{Narrated Humaid:I asked Anas about the fasting of the Prophet. He said "Whenever I liked to see the Prophet (ﷺ) fasting in any month, I could see that, and whenever I liked to see him not fasting, I could see that too, and if I liked to see him praying in any night, I could see that, and if I liked to see him sleeping, I could see that, too." Anas further said, "I never touched silk or velvet softer than the hand of Allah's Messenger (ﷺ) and never smelled musk or perfumed smoke more pleasant than the smell of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{1974}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا هَارُونُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنهما ـ قَالَ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ الْحَدِيثَ يَعْنِي ‏"‏ إِنَّ لِزَوْرِكَ عَلَيْكَ حَقًّا، وَإِنَّ لِزَوْجِكَ عَلَيْكَ حَقًّا ‏"‏‏.‏ فَقُلْتُ وَمَا صَوْمُ دَاوُدَ قَالَ ‏"‏ نِصْفُ الدَّهْرِ ‏"‏‏.‏\hadithno{1974}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:"Once Allah's Messenger (ﷺ) came to me," and then he narrated the whole narration, i.e. your guest has a right on you, and your wife has a right on you. I then asked about the fasting of David. The Prophet (ﷺ) replied, "Half of the year," (i.e. he used to fast on every alternate day)}}
\hadithdefcmd{bukhari}{1975}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنهما ـ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَبْدَ اللَّهِ أَلَمْ أُخْبَرْ أَنَّكَ تَصُومُ النَّهَارَ وَتَقُومُ اللَّيْلَ ‏"‏‏.‏ فَقُلْتُ بَلَى يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلْ، صُمْ وَأَفْطِرْ، وَقُمْ وَنَمْ، فَإِنَّ لِجَسَدِكَ عَلَيْكَ حَقًّا، وَإِنَّ لِعَيْنِكَ عَلَيْكَ حَقًّا، وَإِنَّ لِزَوْجِكَ عَلَيْكَ حَقًّا، وَإِنَّ لِزَوْرِكَ عَلَيْكَ حَقًّا، وَإِنَّ بِحَسْبِكَ أَنْ تَصُومَ كُلَّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ، فَإِنَّ لَكَ بِكُلِّ حَسَنَةٍ عَشْرَ أَمْثَالِهَا، فَإِنَّ ذَلِكَ صِيَامُ الدَّهْرِ كُلِّهِ ‏"‏‏.‏ فَشَدَّدْتُ، فَشُدِّدَ عَلَىَّ، قُلْتُ يَا رَسُولَ اللَّهِ، إِنِّي أَجِدُ قُوَّةً‏.‏ قَالَ ‏"‏ فَصُمْ صِيَامَ نَبِيِّ اللَّهِ دَاوُدَ عَلَيْهِ السَّلاَمُ وَلاَ تَزِدْ عَلَيْهِ ‏"‏‏.‏ قُلْتُ وَمَا كَانَ صِيَامُ نَبِيِّ اللَّهِ دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ قَالَ ‏"‏ نِصْفَ الدَّهْرِ ‏"‏‏.‏ فَكَانَ عَبْدُ اللَّهِ يَقُولُ بَعْدَ مَا كَبِرَ يَا لَيْتَنِي قَبِلْتُ رُخْصَةَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1975}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:Allah's Messenger (ﷺ) said to me, "O `Abdullah! Have I not been informed that you fast during the day and offer prayers all the night." `Abdullah replied, "Yes, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said, "Don't do that; fast for few days and then give it up for few days, offer prayers and also sleep at night, as your body has a right on you, and your wife has a right on you, and your guest has a right on you. And it is sufficient for you to fast three days in a month, as the reward of a good deed is multiplied ten times, so it will be like fasting throughout the year." I insisted (on fasting) and so I was given a hard instruction. I said, "O Allah's Messenger (ﷺ)! I have power." The Prophet (ﷺ) said, "Fast like the fasting of the Prophet David (ﷺ) and do not fast more than that." I said, "How was the fasting of the Prophet of Allah, David (ﷺ)?" He said, "Half of the year," (i.e. he used to fast on every alternate day). Afterwards when `Abdullah became old, he used to say, "It would have been better for me if I had accepted the permission of the Prophet (which he gave me i.e. to fast only three days a month)}}
\hadithdefcmd{bukhari}{1976}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو، قَالَ أُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنِّي أَقُولُ وَاللَّهِ لأَصُومَنَّ النَّهَارَ، وَلأَقُومَنَّ اللَّيْلَ، مَا عِشْتُ‏.‏ فَقُلْتُ لَهُ قَدْ قُلْتُهُ بِأَبِي أَنْتَ وَأُمِّي‏.‏ قَالَ ‏"‏ فَإِنَّكَ لاَ تَسْتَطِيعُ ذَلِكَ، فَصُمْ وَأَفْطِرْ، وَقُمْ وَنَمْ، وَصُمْ مِنَ الشَّهْرِ ثَلاَثَةَ أَيَّامٍ، فَإِنَّ الْحَسَنَةَ بِعَشْرِ أَمْثَالِهَا، وَذَلِكَ مِثْلُ صِيَامِ الدَّهْرِ ‏"‏‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ‏.‏ قَالَ ‏"‏ فَصُمْ يَوْمًا وَأَفْطِرْ يَوْمَيْنِ ‏"‏‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ‏.‏ قَالَ ‏"‏ فَصُمْ يَوْمًا وَأَفْطِرْ يَوْمًا، فَذَلِكَ صِيَامُ دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ وَهْوَ أَفْضَلُ الصِّيَامِ ‏"‏‏.‏ فَقُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ أَفْضَلَ مِنْ ذَلِكَ ‏"‏‏.‏\hadithno{1976}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) was informed that I had taken an oath to fast daily and to pray (every night) all the night throughout my life (so Allah's Messenger (ﷺ) came to me and asked whether it was correct): I replied, "Let my parents be sacrificed for you! I said so." The Prophet (ﷺ) said, "You can not do that. So, fast for few days and give it up for few days, offer Salat (prayer) and sleep. Fast three days a month as the reward of good deeds is multiplied ten times and that will be equal to one year of fasting." I replied, "I can do better than that." The Prophet (ﷺ) said to me, "Fast one day and give up fasting for two days." I replied, "I can do better than that." The Prophet (ﷺ) said to me, "Fast one day and give up fasting for a day and that is the fasting of Prophet David and that is the best fasting." I said, "I have the power to fast better (more) than that." The Prophet (ﷺ) said, "There is no better fasting than that}}
\hadithdefcmd{bukhari}{1977}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، أَخْبَرَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، سَمِعْتُ عَطَاءً، أَنَّ أَبَا الْعَبَّاسِ الشَّاعِرَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو ـ رضى الله عنهما ـ بَلَغَ النَّبِيَّ صلى الله عليه وسلم أَنِّي أَسْرُدُ الصَّوْمَ وَأُصَلِّي اللَّيْلَ، فَإِمَّا أَرْسَلَ إِلَىَّ، وَإِمَّا لَقِيتُهُ، فَقَالَ ‏"‏ أَلَمْ أُخْبَرْ أَنَّكَ تَصُومُ وَلاَ تُفْطِرُ، وَتُصَلِّي وَلاَ تَنَامُ، فَصُمْ وَأَفْطِرْ، وَقُمْ وَنَمْ، فَإِنَّ لِعَيْنِكَ عَلَيْكَ حَظًّا، وَإِنَّ لِنَفْسِكَ وَأَهْلِكَ عَلَيْكَ حَظًّا ‏"‏‏.‏ قَالَ إِنِّي لأَقْوَى لِذَلِكَ‏.‏ قَالَ ‏"‏ فَصُمْ صِيَامَ دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ ‏"‏‏.‏ قَالَ وَكَيْفَ قَالَ ‏"‏ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا، وَلاَ يَفِرُّ إِذَا لاَقَى ‏"‏‏.‏ قَالَ مَنْ لِي بِهَذِهِ يَا نَبِيَّ اللَّهِ قَالَ عَطَاءٌ لاَ أَدْرِي كَيْفَ ذَكَرَ صِيَامَ الأَبَدِ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ صَامَ مَنْ صَامَ الأَبَدَ ‏"‏‏.‏ مَرَّتَيْنِ‏.‏\hadithno{1977}\hadithtrans{Narrated `Abdullah bin `Amr:The news of my daily fasting and praying every night throughout the night reached the Prophet. So he sent for me or I met him, and he said, "I have been informed that you fast everyday and pray every night (all the night). Fast (for some days) and give up fasting (for some days); pray and sleep, for your eyes have a right on you, and your body and your family (i.e. wife) have a right on you." I replied, "I have more power than that (fasting)." The Prophet (ﷺ) said, "Then fast like the fasts of (the Prophet) David". I said, "How?" He replied, "He used to fast on alternate days, and he used not to flee on meeting the enemy." I said, "From where can I get that chance?" (`Ata' said, "I do not know how the expression of fasting daily throughout the life occurred.") So, the Prophet (ﷺ) said, twice, "Whoever fasts daily throughout his life is just as the one who does not fast at all}}
\hadithdefcmd{bukhari}{1978}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُغِيرَةَ، قَالَ سَمِعْتُ مُجَاهِدًا، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ صُمْ مِنَ الشَّهْرِ ثَلاَثَةَ أَيَّامٍ ‏"‏‏.‏ قَالَ أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ‏.‏ فَمَا زَالَ حَتَّى قَالَ ‏"‏ صُمْ يَوْمًا وَأَفْطِرْ يَوْمًا ‏"‏ فَقَالَ ‏"‏ اقْرَإِ الْقُرْآنَ فِي شَهْرٍ ‏"‏‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ‏.‏ فَمَا زَالَ حَتَّى قَالَ فِي ثَلاَثٍ‏.‏\hadithno{1978}\hadithtrans{Narrated Mujahid from `Abdullah bin `Amr:The Prophet (ﷺ) said (to `Abdullah), "Fast three days a month." `Abdullah said, (to the Prophet) "I am able to fast more than that." They kept on arguing on this matter till the Prophet (ﷺ) said, "Fast on alternate days, and recite the whole Qur'an once a month." `Abdullah said, "I can recite more (in a month)," and the argument went on till the Prophet (ﷺ) said, "Recite the Qur'an once each three days." (i.e. you must not recite the whole Qur'an in less than three days)}}
\hadithdefcmd{bukhari}{1979}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، قَالَ سَمِعْتُ أَبَا الْعَبَّاسِ الْمَكِّيَّ ـ وَكَانَ شَاعِرًا وَكَانَ لاَ يُتَّهَمُ فِي حَدِيثِهِ ـ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنهما ـ قَالَ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّكَ لَتَصُومُ الدَّهْرَ، وَتَقُومُ اللَّيْلَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ إِنَّكَ إِذَا فَعَلْتَ ذَلِكَ هَجَمَتْ لَهُ الْعَيْنُ وَنَفِهَتْ لَهُ النَّفْسُ، لاَ صَامَ مَنْ صَامَ الدَّهْرَ، صَوْمُ ثَلاَثَةِ أَيَّامٍ صَوْمُ الدَّهْرِ كُلِّهِ ‏"‏‏.‏ قُلْتُ فَإِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ‏.‏ قَالَ ‏"‏ فَصُمْ صَوْمَ دَاوُدَ عَلَيْهِ السَّلاَمُ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا، وَلاَ يَفِرُّ إِذَا لاَقَى ‏"‏‏.‏\hadithno{1979}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:The Prophet (ﷺ) said to me, "You fast daily all the year and pray every night all the night?" I replied in the affirmative. The Prophet (ﷺ) said, "If you keep on doing this, your eyes will become weak and your body will get tired. He who fasts all the year is as he who did not fast at all. The fasting of three days (a month) will be equal to the fasting of the whole year." I replied, "I have the power for more than this." The Prophet (ﷺ) said, "Then fast like the fasting of David who used to fast on alternate days and would never flee from the battle field, on meeting the enemy}}
\hadithdefcmd{bukhari}{1980}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، قَالَ أَخْبَرَنِي أَبُو الْمَلِيحِ، قَالَ دَخَلْتُ مَعَ أَبِيكَ عَلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذُكِرَ لَهُ صَوْمِي فَدَخَلَ عَلَىَّ، فَأَلْقَيْتُ لَهُ وِسَادَةً مِنْ أَدَمٍ، حَشْوُهَا لِيفٌ، فَجَلَسَ عَلَى الأَرْضِ، وَصَارَتِ الْوِسَادَةُ بَيْنِي وَبَيْنَهُ‏.‏ فَقَالَ ‏"‏ أَمَا يَكْفِيكَ مِنْ كُلِّ شَهْرٍ ثَلاَثَةُ أَيَّامٍ ‏"‏‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ خَمْسًا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ سَبْعًا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ تِسْعًا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ إِحْدَى عَشْرَةَ ‏"‏‏.‏ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ صَوْمَ فَوْقَ صَوْمِ دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ شَطْرَ الدَّهْرِ، صُمْ يَوْمًا، وَأَفْطِرْ يَوْمًا ‏"‏‏.‏\hadithno{1980}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) was informed about my fasts, and he came to me and I spread for him a leather cushion stuffed with palm fibres, but he sat on the ground and the cushion remained between me and him, and then he said, "Isn't it sufficient for you to fast three days a month?" I replied, "O Allah's Apostle! (I can fast more)." He said, "Five?" I replied, "O Allah's Messenger (ﷺ)! (I can fast more)." He said, "Seven?" I replied, "O Allah's Messenger (ﷺ)! (I can fast more)." He said, "Nine (days per month)?" I replied, "O Allah's Messenger (ﷺ)! (I can fast more)" He said, "Eleven (days per month)?" And then the Prophet said, "There is no fast superior to that of the Prophet David (ﷺ) it was for half of the year. So, fast on alternate days}}
\hadithdefcmd{bukhari}{1981}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَبُو التَّيَّاحِ، قَالَ حَدَّثَنِي أَبُو عُثْمَانَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَوْصَانِي خَلِيلِي صلى الله عليه وسلم بِثَلاَثٍ صِيَامِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ، وَرَكْعَتَىِ الضُّحَى، وَأَنْ أُوتِرَ قَبْلَ أَنْ أَنَامَ‏.‏\hadithno{1981}\hadithtrans{Narrated Abu Huraira:My friend (the Prophet (ﷺ) ) advised me to observe three things: (1) to fast three days a month; (2) to pray two rak`at of Duha prayer (forenoon prayer); and (3) to pray witr before sleeping}}
\hadithdefcmd{bukhari}{1982}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي خَالِدٌ ـ هُوَ ابْنُ الْحَارِثِ ـ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى أُمِّ سُلَيْمٍ، فَأَتَتْهُ بِتَمْرٍ وَسَمْنٍ، قَالَ ‏"‏ أَعِيدُوا سَمْنَكُمْ فِي سِقَائِهِ، وَتَمْرَكُمْ فِي وِعَائِهِ، فَإِنِّي صَائِمٌ ‏"‏‏.‏ ثُمَّ قَامَ إِلَى نَاحِيَةٍ مِنَ الْبَيْتِ، فَصَلَّى غَيْرَ الْمَكْتُوبَةِ، فَدَعَا لأُمِّ سُلَيْمٍ، وَأَهْلِ بَيْتِهَا، فَقَالَتْ أُمُّ سُلَيْمٍ يَا رَسُولَ اللَّهِ، إِنَّ لِي خُوَيْصَةً، قَالَ ‏"‏ مَا هِيَ ‏"‏‏.‏ قَالَتْ خَادِمُكَ أَنَسٌ‏.‏ فَمَا تَرَكَ خَيْرَ آخِرَةٍ وَلاَ دُنْيَا إِلاَّ دَعَا لِي بِهِ قَالَ ‏"‏ اللَّهُمَّ ارْزُقْهُ مَالاً وَوَلَدًا وَبَارِكْ لَهُ ‏"‏‏.‏ فَإِنِّي لَمِنْ أَكْثَرِ الأَنْصَارِ مَالاً‏.‏ وَحَدَّثَتْنِي ابْنَتِي أُمَيْنَةُ أَنَّهُ دُفِنَ لِصُلْبِي مَقْدَمَ حَجَّاجٍ الْبَصْرَةَ بِضْعٌ وَعِشْرُونَ وَمِائَةٌ‏.‏ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا يَحْيَى، قَالَ حَدَّثَنِي حُمَيْدٌ، سَمِعَ أَنَسًا ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1982}\hadithtrans{Narrated Anas:The Prophet (ﷺ) paid a visit to Um-Sulaim and she placed before him dates and ghee. The Prophet (ﷺ) said, "Replace the ghee and dates in their respective containers for I am fasting." Then he stood somewhere in her house and offered an optional prayer and then he invoked good on Um-Sulaim and her family. Then Um-Sulaim said, "O Allah's Messenger (ﷺ)! I have a special request (today)." He said, "What is it?" She replied, "(Please invoke for) your servant Anas." So Allah's Messenger (ﷺ) did not leave anything good in the world or the Hereafter which he did not invoke (Allah to bestow) on me and said, "O Allah! Give him (i.e. Anas) property and children and bless him." Thus I am one of the richest among the Ansar and my daughter Umaina told me that when Al-Hajjaj came to Basra, more than 120 of my offspring had been buried}}
\hadithdefcmd{bukhari}{1983}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا مَهْدِيٌّ، عَنْ غَيْلاَنَ،‏.‏ وَحَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ أَنَّهُ سَأَلَهُ ـ أَوْ سَأَلَ رَجُلاً وَعِمْرَانُ يَسْمَعُ ـ فَقَالَ ‏"‏ يَا أَبَا فُلاَنٍ أَمَا صُمْتَ سَرَرَ هَذَا الشَّهْرِ ‏"‏‏.‏ قَالَ أَظُنُّهُ قَالَ يَعْنِي رَمَضَانَ‏.‏ قَالَ الرَّجُلُ لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِذَا أَفْطَرْتَ فَصُمْ يَوْمَيْنِ ‏"‏‏.‏ لَمْ يَقُلِ الصَّلْتُ أَظُنُّهُ يَعْنِي رَمَضَانَ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ ثَابِثٌ عَنْ مُطَرِّفٍ عَنْ عِمْرَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ مِنْ سَرَرِ شَعْبَانَ ‏"‏‏.‏\hadithno{1983}\hadithtrans{Narrated Mutarrif from `Imran Ibn Husain:That the Prophet (ﷺ) asked him (Imran) or asked a man and `Imran was listening, "O Abu so-and-so! Have you fasted the last days of this month?" (The narrator thought that he said, "the month of Ramadan"). The man replied, "No, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said to him, "When you finish your fasting (of Ramadan) fast two days (in Shawwal)." Through another series of narrators `Imran said, "The Prophet (ﷺ) said, '(Have you fasted) the last days of Sha'ban?}}
\hadithdefcmd{bukhari}{1984}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ عَبَّادٍ، قَالَ سَأَلْتُ جَابِرًا ـ رضى الله عنه ـ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ صَوْمِ يَوْمِ الْجُمُعَةِ قَالَ نَعَمْ‏.‏ زَادَ غَيْرُ أَبِي عَاصِمٍ أَنْ يَنْفَرِدَ بِصَوْمٍ‏.‏\hadithno{1984}\hadithtrans{Narrated Muhammad bin `Abbas:I asked Jabir "Did the Prophet (ﷺ) forbid fasting on Fridays?" He replied, "Yes." (Other narrators added, "If he intends to fast only that day)}}
\hadithdefcmd{bukhari}{1985}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَصُومَنَّ أَحَدُكُمْ يَوْمَ الْجُمُعَةِ، إِلاَّ يَوْمًا قَبْلَهُ أَوْ بَعْدَهُ ‏"‏‏.‏\hadithno{1985}\hadithtrans{Narrated Abu Huraira:I heard the Prophet (ﷺ) saying, "None of you should fast on Friday unless he fasts a day before or after it}}
\hadithdefcmd{bukhari}{1986}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، ح‏.‏ وَحَدَّثَنِي مُحَمَّدٌ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي أَيُّوبَ، عَنْ جُوَيْرِيَةَ بِنْتِ الْحَارِثِ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا يَوْمَ الْجُمُعَةِ وَهْىَ صَائِمَةٌ فَقَالَ ‏"‏ أَصُمْتِ أَمْسِ ‏"‏‏.‏ قَالَتْ لاَ‏.‏ قَالَ ‏"‏ تُرِيدِينَ أَنْ تَصُومِي غَدًا ‏"‏‏.‏ قَالَتْ لاَ‏.‏ قَالَ ‏"‏ فَأَفْطِرِي ‏"‏‏.‏ وَقَالَ حَمَّادُ بْنُ الْجَعْدِ سَمِعَ قَتَادَةَ حَدَّثَنِي أَبُو أَيُّوبَ أَنَّ جُوَيْرِيَةَ حَدَّثَتْهُ فَأَمَرَهَا فَأَفْطَرَتْ\hadithno{1986}\hadithtrans{Narrated Abu Aiyub from Juwairiya bint Al-Harith:The Prophet (ﷺ) visited her (Juwairiya) on a Friday and she was fasting. He asked her, "Did you fast yesterday?" She said, "No." He said, "Do you intend to fast tomorrow?" She said, "No." He said, "Then break your fast." Through another series of narrators, Abu Aiyub is reported to have said, "He ordered her and she broke her fast}}
\hadithdefcmd{bukhari}{1987}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قُلْتُ لِعَائِشَةَ ـ رضى الله عنها ـ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْتَصُّ مِنَ الأَيَّامِ شَيْئًا قَالَتْ لاَ، كَانَ عَمَلُهُ دِيمَةً، وَأَيُّكُمْ يُطِيقُ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُطِيقُ\hadithno{1987}\hadithtrans{Narrated Alqama:I asked `Aisha "Did Allah's Apostle, use to choose some special days (for fasting)?" She replied, "No, but he used to be regular (constant) (in his service of worshipping). Who amongst you can endure what Allah's Messenger (ﷺ) used to endure?}}
\hadithdefcmd{bukhari}{1988}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي سَالِمٌ، قَالَ حَدَّثَنِي عُمَيْرٌ، مَوْلَى أُمِّ الْفَضْلِ أَنَّ أُمَّ، الْفَضْلِ حَدَّثَتْهُ ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ أَخْبَرَنَا مَالِكٌ عَنْ أَبِي النَّضْرِ مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عُمَيْرٍ مَوْلَى عَبْدِ اللَّهِ بْنِ الْعَبَّاسِ عَنْ أُمِّ الْفَضْلِ بِنْتِ الْحَارِثِ أَنَّ نَاسًا تَمَارَوْا عِنْدَهَا يَوْمَ عَرَفَةَ فِي صَوْمِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ بَعْضُهُمْ هُوَ صَائِمٌ‏.‏ وَقَالَ بَعْضُهُمْ لَيْسَ بِصَائِمٍ‏.‏ فَأَرْسَلَتْ إِلَيْهِ بِقَدَحِ لَبَنٍ وَهْوَ وَاقِفٌ عَلَى بَعِيرِهِ فَشَرِبَهُ‏.‏\hadithno{1988}\hadithtrans{Narrated Um Al-Fadl bint Al-Harith:"While the people were with me on the day of `Arafat they differed as to whether the Prophet (ﷺ) was fasting or not; some said that he was fasting while others said that he was not fasting. So, I sent to him a bowl full of milk while he was riding over his camel and he drank it}}
\hadithdefcmd{bukhari}{1989}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ وَهْبٍ ـ أَوْ قُرِئَ عَلَيْهِ ـ قَالَ أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرٍ، عَنْ كُرَيْبٍ، عَنْ مَيْمُونَةَ ـ رضى الله عنها ـ أَنَّ النَّاسَ، شَكُّوا فِي صِيَامِ النَّبِيِّ صلى الله عليه وسلم يَوْمَ عَرَفَةَ، فَأَرْسَلَتْ إِلَيْهِ بِحِلاَبٍ وَهْوَ وَاقِفٌ فِي الْمَوْقِفِ، فَشَرِبَ مِنْهُ، وَالنَّاسُ يَنْظُرُونَ‏.‏\hadithno{1989}\hadithtrans{Narrated Maimuna:The people doubted whether the Prophet (ﷺ) was fasting on the day of `Arafat or not, so I sent milk while he was standing at `Arafat, he drank it and the people were looking at him}}
\hadithdefcmd{bukhari}{1990}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى ابْنِ أَزْهَرَ قَالَ شَهِدْتُ الْعِيدَ مَعَ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ فَقَالَ هَذَانِ يَوْمَانِ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صِيَامِهِمَا يَوْمُ فِطْرِكُمْ مِنْ صِيَامِكُمْ، وَالْيَوْمُ الآخَرُ تَأْكُلُونَ فِيهِ مِنْ نُسُكِكُمْ‏.‏ قَالَ أَبُو عَبْد اللَّهِ قَالَ ابْنُ عُيَيْنَةَ مَنْ قَالَ مَوْلَى ابْنِ أَزْهَرَ فَقَدْ أَصَابَ وَمَنْ قَالَ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ فَقَدْ أَصَابَ\hadithno{1990}\hadithtrans{Narrated Abu `Ubaid:(the slave of Ibn Azhar) I witnessed the `Id with `Umar bin Al-Khattab who said, Allah's Messenger (ﷺ) has forbidden people to fast on the day on which you break fasting (the fasts of Ramadan) and the day on which you eat the meat of your sacrifices (the first day of `Id ul Fitr and `Id ul-Adha)}}
\hadithdefcmd{bukhari}{1992}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ صَوْمِ يَوْمِ الْفِطْرِ وَالنَّحْرِ، وَعَنِ الصَّمَّاءِ، وَأَنْ يَحْتَبِيَ الرَّجُلُ فِي ثَوْبٍ وَاحِدٍ‏.‏ وَعَنْ صَلاَةٍ، بَعْدَ الصُّبْحِ وَالْعَصْرِ‏.‏\hadithno{1992}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) forbade the fasting of `Id-ul-Fitr and `Id-ul-Adha (two feast days) and also the wearing of As-Samma' (a single garment covering the whole body), and sitting with one's leg drawn up while being wrapped in one garment. He also forbade the prayers after the Fajr (morning) and the `Asr (afternoon) prayers}}
\hadithdefcmd{bukhari}{1993}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ عَطَاءِ بْنِ مِينَا، قَالَ سَمِعْتُهُ يُحَدِّثُ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ يُنْهَى عَنْ صِيَامَيْنِ، وَبَيْعَتَيْنِ الْفِطْرِ، وَالنَّحْرِ،، وَالْمُلاَمَسَةِ، وَالْمُنَابَذَةِ،‏.‏\hadithno{1993}\hadithtrans{Narrated Abu Huraira:Two fasts and two kinds of sale are forbidden: fasting on the day of `Id ul Fitr and `Id-ul-Adha and the kinds of sale called Mulamasa and Munabadha. (These two kinds of sale used to be practiced in the days of Pre-Islamic period of ignorance; Mulamasa means when you touch something displayed for sale you have to buy it; Munabadha means when the seller throws something to you, you have to buy it)}}
\hadithdefcmd{bukhari}{1994}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذٌ، أَخْبَرَنَا ابْنُ عَوْنٍ، عَنْ زِيَادِ بْنِ جُبَيْرٍ، قَالَ جَاءَ رَجُلٌ إِلَى ابْنِ عُمَرَ ـ رضى الله عنهما ـ فَقَالَ رَجُلٌ نَذَرَ أَنْ يَصُومَ يَوْمًا، قَالَ أَظُنُّهُ قَالَ الاِثْنَيْنِ، فَوَافَقَ يَوْمَ عِيدٍ‏.‏ فَقَالَ ابْنُ عُمَرَ أَمَرَ اللَّهُ بِوَفَاءِ النَّذْرِ، وَنَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ صَوْمِ هَذَا الْيَوْمِ‏.‏\hadithno{1994}\hadithtrans{Narrated Ziyad bin Jubair:A man went to Ibn `Umar and said, "A man vowed to fast one day (the sub-narrator thinks that he said that the day was Monday), and that day happened to be `Id day." Ibn `Umar said, "Allah orders vows to be fulfilled and the Prophet (ﷺ) forbade the fasting on this day (i.e. Id)}}
\hadithdefcmd{bukhari}{1995}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، قَالَ سَمِعْتُ قَزَعَةَ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ وَكَانَ غَزَا مَعَ النَّبِيِّ صلى الله عليه وسلم ثِنْتَىْ عَشْرَةَ غَزْوَةً قَالَ سَمِعْتُ أَرْبَعًا مِنَ النَّبِيِّ صلى الله عليه وسلم فَأَعْجَبْنَنِي قَالَ ‏ "‏ لاَ تُسَافِرِ الْمَرْأَةُ مَسِيرَةَ يَوْمَيْنِ إِلاَّ وَمَعَهَا زَوْجُهَا أَوْ ذُو مَحْرَمٍ، وَلاَ صَوْمَ فِي يَوْمَيْنِ الْفِطْرِ وَالأَضْحَى، وَلاَ صَلاَةَ بَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ، وَلاَ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ، وَلاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِ الْحَرَامِ، وَمَسْجِدِ الأَقْصَى، وَمَسْجِدِي هَذَا ‏"‏‏.‏\hadithno{1995}\hadithtrans{Narrated Abu Sa`id Al-Khudri:(who fought in twelve Ghazawat in the company of the Prophet). I heard four things from the Prophet (ﷺ) and they won my admiration. He said; -1. "No lady should travel on a journey of two days except with her husband or a Dhi-Mahram; -2. "No fasting is permissible on the two days of Id-ul-Fitr and `Id-ul-Adha; -3. "No prayer (may be offered) after the morning compulsory prayer until the sun rises; and no prayer after the `Asr prayer till the sun sets; -4. "One should travel only for visiting three Masjid (Mosques): Masjid-al-Haram (Mecca), Masjid-al- Aqsa (Jerusalem), and this (my) Mosque (at Medina)}}
\hadithdefcmd{bukhari}{1996}{وَقَالَ لِي مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي كَانَتْ، عَائِشَةُ ـ رضى الله عنها ـ تَصُومُ أَيَّامَ مِنًى، وَكَانَ أَبُوهَا يَصُومُهَا‏.‏\hadithno{1996}\hadithtrans{Narrated Yahya:Hisham said, "My father said that 'Aishah (ra) used to observe Saum (fast) on the days of Mina." His (i.e., Hisham's) father also used to observe Saum on those days}}
\hadithdefcmd{bukhari}{1998}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ عِيسَى، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ،‏.‏ وَعَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهم ـ قَالاَ لَمْ يُرَخَّصْ فِي أَيَّامِ التَّشْرِيقِ أَنْ يُصَمْنَ، إِلاَّ لِمَنْ لَمْ يَجِدِ الْهَدْىَ‏.‏\hadithno{1998}\hadithtrans{Narrated `Aisha and Ibn `Umar:Nobody was allowed to fast on the days of Tashriq except those who could not afford the Hadi (Sacrifice)}}
\hadithdefcmd{bukhari}{1999}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ الصِّيَامُ لِمَنْ تَمَتَّعَ بِالْعُمْرَةِ إِلَى الْحَجِّ، إِلَى يَوْمِ عَرَفَةَ، فَإِنْ لَمْ يَجِدْ هَدْيًا وَلَمْ يَصُمْ صَامَ أَيَّامَ مِنًى‏.‏ وَعَنِ ابْنِ شِهَابٍ عَنْ عُرْوَةَ عَنْ عَائِشَةَ مِثْلَهُ‏.‏ تَابَعَهُ إِبْرَاهِيمُ بْنُ سَعْدٍ عَنِ ابْنِ شِهَابٍ‏.‏\hadithno{1999}\hadithtrans{Narrated Ibn `Umar:Fasting for those who perform ,Hajj-at-Tamattu` (in lieu of the Hadi which they cannot afford) may be performed up to the day of `Arafat. And if one does not get a Hadi and has not fasted (before the `Id) then one should fast of the days of Mina. (11th, 12th and 13th of Dhul Hijjah)}}
\hadithdefcmd{bukhari}{2000}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُمَرَ بْنِ مُحَمَّدٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ عَاشُورَاءَ ‏ "‏ إِنْ شَاءَ صَامَ ‏"‏‏.‏\hadithno{2000}\hadithtrans{Narrated Salim's father:The Prophet (ﷺ) said, "Whoever wishes may fast on the day of 'Ashura}}
\hadithdefcmd{bukhari}{2001}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَمَرَ بِصِيَامِ يَوْمِ عَاشُورَاءَ، فَلَمَّا فُرِضَ رَمَضَانُ كَانَ مَنْ شَاءَ صَامَ، وَمَنْ شَاءَ أَفْطَرَ‏.‏\hadithno{2001}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) ordered (the Muslims) to fast on the day of 'Ashura', and when fasting in the month of Ramadan was prescribed, it became optional for one to fast on that day ('Ashura') or not}}
\hadithdefcmd{bukhari}{2002}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ يَوْمُ عَاشُورَاءَ تَصُومُهُ قُرَيْشٌ فِي الْجَاهِلِيَّةِ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُهُ، فَلَمَّا قَدِمَ الْمَدِينَةَ صَامَهُ، وَأَمَرَ بِصِيَامِهِ، فَلَمَّا فُرِضَ رَمَضَانُ تَرَكَ يَوْمَ عَاشُورَاءَ، فَمَنْ شَاءَ صَامَهُ، وَمَنْ شَاءَ تَرَكَهُ‏.‏\hadithno{2002}\hadithtrans{Narrated Aisha:Quraish used to fast on the day of 'Ashura' in the Pre-Islamic period, and Allah's Messenger (ﷺ) too, used to fast on that day. When he came to Medina, he fasted on that day and ordered others to fast, too. Later when the fasting of the month of Ramadan was prescribed, he gave up fasting on the day of 'Ashura' and it became optional for one to fast on it or not}}
\hadithdefcmd{bukhari}{2003}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ ـ رضى الله عنهما ـ يَوْمَ عَاشُورَاءَ عَامَ حَجَّ عَلَى الْمِنْبَرِ يَقُولُ يَا أَهْلَ الْمَدِينَةِ، أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ هَذَا يَوْمُ عَاشُورَاءَ، وَلَمْ يُكْتَبْ عَلَيْكُمْ صِيَامُهُ، وَأَنَا صَائِمٌ، فَمَنْ شَاءَ فَلْيَصُمْ وَمَنْ شَاءَ فَلْيُفْطِرْ ‏"‏‏.‏\hadithno{2003}\hadithtrans{Narrated Humaid bin `Abdur Rahman:That he heard Muawiya bin Abi Sufyan on the day of 'Ashura' during the year he performed the Hajj, saying on the pulpit, "O the people of Medina! Where are your Religious Scholars? I heard Allah's Apostle saying, 'This is the day of 'Ashura'. Allah has not enjoined its fasting on you but I am fasting it. You have the choice either to fast or not to fast (on this day)}}
\hadithdefcmd{bukhari}{2004}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ، فَرَأَى الْيَهُودَ تَصُومُ يَوْمَ عَاشُورَاءَ، فَقَالَ ‏"‏ مَا هَذَا ‏"‏‏.‏ قَالُوا هَذَا يَوْمٌ صَالِحٌ، هَذَا يَوْمٌ نَجَّى اللَّهُ بَنِي إِسْرَائِيلَ مِنْ عَدُوِّهِمْ، فَصَامَهُ مُوسَى‏.‏ قَالَ ‏"‏ فَأَنَا أَحَقُّ بِمُوسَى مِنْكُمْ ‏"‏‏.‏ فَصَامَهُ وَأَمَرَ بِصِيَامِهِ‏.‏\hadithno{2004}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) came to Medina and saw the Jews fasting on the day of Ashura. He asked them about that. They replied, "This is a good day, the day on which Allah rescued Bani Israel from their enemy. So, Moses fasted this day." The Prophet (ﷺ) said, "We have more claim over Moses than you." So, the Prophet fasted on that day and ordered (the Muslims) to fast (on that day)}}
\hadithdefcmd{bukhari}{2005}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ أَبِي عُمَيْسٍ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ كَانَ يَوْمُ عَاشُورَاءَ تَعُدُّهُ الْيَهُودُ عِيدًا، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ فَصُومُوهُ أَنْتُمْ ‏"‏‏.‏\hadithno{2005}\hadithtrans{Narrated Abu Musa:The day of 'Ashura' was considered as `Id day by the Jews. So the Prophet (ﷺ) ordered, "I recommend you (Muslims) to fast on this day}}
\hadithdefcmd{bukhari}{2006}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنِ ابْنِ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَتَحَرَّى صِيَامَ يَوْمٍ فَضَّلَهُ عَلَى غَيْرِهِ، إِلاَّ هَذَا الْيَوْمَ يَوْمَ عَاشُورَاءَ وَهَذَا الشَّهْرَ‏.‏ يَعْنِي شَهْرَ رَمَضَانَ‏.‏\hadithno{2006}\hadithtrans{Narrated Ibn `Abbas:I never saw the Prophet (ﷺ) seeking to fast on a day that he favored more than another except this day, the day of 'Ashura', and this month, meaning the month of Ramadan}}
\hadithdefcmd{bukhari}{2007}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَزِيدُ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ ـ رضى الله عنه ـ قَالَ أَمَرَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً مِنْ أَسْلَمَ أَنْ أَذِّنْ فِي النَّاسِ ‏ "‏ أَنَّ مَنْ كَانَ أَكَلَ فَلْيَصُمْ بَقِيَّةَ يَوْمِهِ، وَمَنْ لَمْ يَكُنْ أَكَلَ فَلْيَصُمْ، فَإِنَّ الْيَوْمَ يَوْمُ عَاشُورَاءَ ‏"‏‏.‏\hadithno{2007}\hadithtrans{Narrated Salama bin Al-Akwa`:The Prophet (ﷺ) ordered a man from the tribe of Bani Aslam to announce amongst the people that whoever had eaten should fast the rest of the day, and whoever had not eaten should continue his fast, as that day was the day of 'Ashura}}
